/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;

import com.aionemu.commons.database.DatabaseFactory;
import com.aionemu.gameserver.dao.MemberShipDAO;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.model.account.MemberShipEffect;
import com.aionemu.gameserver.model.gameobjects.player.MemberShipInfo;
import com.aionemu.gameserver.model.gameobjects.player.Player;

/**
 * @author zxl001
 */
public class MYSQL5MemberShipDAO extends MemberShipDAO {

	public static final String SELECT_QUERY = "SELECT `buff_id`, `retime` FROM `membership` WHERE `object_id` = ?";
	public static final String INSERT_QUERY = "INSERT INTO `membership` (`object_id`, `buff_id`, `retime`) VALUES (?,?,?)";
	public static final String DELETE_QUERY = "DELETE FROM `membership` WHERE `object_id`=? AND `buff_id`=?";
	public static final String UPDATE_QUERY = "UPDATE `membership` SET `retime`=? WHERE `object_id`=? AND `buff_id`=?";
	
	@Override
	public void loadMemberShipInfo(Player player) {
		Connection con = null;
		MemberShipInfo info = new MemberShipInfo();
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement st = con.prepareStatement(SELECT_QUERY);
			st.setInt(1, player.getObjectId());
			ResultSet rs = st.executeQuery();
			while (rs.next()) {
				int buff_id = rs.getInt("buff_id");
				long retime = rs.getLong("retime");
				if (retime <= System.currentTimeMillis())
					deleteMemberShipInfo(player.getObjectId(), buff_id);
				else
					info.put(buff_id, new MemberShipEffect(buff_id, retime));
			}
			rs.close();
			st.close();
		}
		catch (Exception e) {
			
		}
		finally {
			DatabaseFactory.close(con);
			player.setMemberShipInfo(info);
		}
	}
	
	@Override
	public void insertMemberShipInfo(final int accountId, final int buffId, final long retime) {
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement ps = con.prepareStatement(INSERT_QUERY);
			ps.setInt(1, accountId);
			ps.setInt(2, buffId);
			ps.setLong(3, retime);
			ps.execute();
			ps.close();
		}
		catch(Exception e) {
			
		}
		finally {
			DatabaseFactory.close(con);
		}
	}

	@Override
	public void deleteMemberShipInfo(final int accountId, final int buffId) {
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement ps = con.prepareStatement(DELETE_QUERY);
			ps.setInt(1, accountId);
			ps.setInt(2, buffId);
			ps.execute();
			ps.close();
		}
		catch (Exception e) {
			
		}
		finally {
			DatabaseFactory.close(con);
		}
	}

	@Override
	public void updataMemberShipInfo(final int accountId, final int buffId, final long retime) {
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement ps = con.prepareStatement(UPDATE_QUERY);
			ps.setLong(1, retime);
			ps.setInt(2, accountId);
			ps.setInt(3, buffId);
			ps.execute();
			ps.close();
		}
		catch (Exception e) {
			
		}
		finally {
			DatabaseFactory.close(con);
		}
	}

	@Override
	public boolean supports(String database, int majorVersion, int minorVersion) {
		return MySQL5DAOUtils.supports(database, majorVersion, minorVersion);
	}
}
