/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import com.aionemu.commons.database.DatabaseFactory;
import com.aionemu.gameserver.dao.CustomEnchantDAO;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.model.gameobjects.PersistentState;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.services.custom.CustomEnchant;
import com.aionemu.gameserver.services.custom.CustomEnchantInfo;
import com.aionemu.gameserver.services.custom.CustomEnchantType;

/**
 * @author zxl001
 */
public class MySQL5CustomEnchantDAO extends CustomEnchantDAO {

	@Override
	public boolean supports(String databaseName, int majorVersion, int minorVersion) {
		return MySQL5DAOUtils.supports(databaseName, majorVersion, minorVersion);
	}

	@Override
	public void loadCustomEnchantInfo(Player player) {
		Map<CustomEnchantType, CustomEnchant> enchantinfos = new HashMap<CustomEnchantType, CustomEnchant>();
		CustomEnchantInfo enchant = new CustomEnchantInfo();
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement stmt = con.prepareStatement("SELECT * FROM `enchant_info` WHERE `object_id`=?");
			stmt.setInt(1, player.getObjectId());
			ResultSet rset = stmt.executeQuery();
			while(rset.next()) {
				CustomEnchantType type = CustomEnchantType.valueOf(rset.getString("enchant_type"));
				int point = rset.getInt("point");
				enchantinfos.put(type, new CustomEnchant(type, point));
			}
			enchant.setEnchantInfo(enchantinfos);
			player.setCustomEnchantInfo(enchant);
			rset.close();
			stmt.close();
		}
		catch (Exception e) {
			// TODO: handle exception
		}
		finally {
			DatabaseFactory.close(con);
		}
	}

	@Override
	public void store(Player player) {
		Collection<CustomEnchant> enchants = player.getCustomEnchantInfo().getEnchants();
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			con.setAutoCommit(false);
			for(CustomEnchant enchant : enchants) {
				if (enchant.getPersistentState() == PersistentState.NEW)
					insertEnchant(con, player.getObjectId(), enchant);
				if (enchant.getPersistentState() == PersistentState.UPDATE_REQUIRED)
					updataEnchant(con, player.getObjectId(), enchant);
			}
			for(CustomEnchant enchant : enchants)
				enchant.setPersistentState(PersistentState.UPDATED);
		}
		catch (Exception e) {
			// TODO: handle exception
		}
		finally {
			DatabaseFactory.close(con);
		}
	}
	
	private void insertEnchant(Connection con, int object_id, CustomEnchant enchant) {
		PreparedStatement stmt = null;
		try {
			stmt = con.prepareStatement("INSERT INTO enchant_info(object_id, enchant_type, point)" + "VALUES (?, ?, ?)");
			stmt.setInt(1, object_id);
			stmt.setString(2, enchant.getCustomEnchantType().toString());
			stmt.setInt(3, enchant.getPoint());
			stmt.execute();
			stmt.close();
		}
		catch (Exception e) {
			// TODO: handle exception
		}
	}
	
	private void updataEnchant(Connection con, int object_id, CustomEnchant enchant) {
		PreparedStatement stmt = null;
		try {
			stmt = con.prepareStatement("UPDATE enchant_info SET point=? WHERE object_id=? AND enchant_type=?");
			stmt.setInt(1, enchant.getPoint());
			stmt.setInt(2, object_id);
			stmt.setString(3, enchant.getCustomEnchantType().toString());
			stmt.execute();
			stmt.close();
		}
		catch (Exception e) {
			// TODO: handle exception
		}
	}

	@Override
	public void reset() {
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement stmt = con.prepareStatement("UPDATE enchant_info SET point=?");
			stmt.setInt(1, 0);
			stmt.execute();
			stmt.close();
		}
		catch (Exception e) {
			// TODO: handle exception
		}
		finally {
			DatabaseFactory.close(con);
		}
	}
}
