/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import com.aionemu.commons.database.DB;
import com.aionemu.commons.database.ReadStH;
import com.aionemu.gameserver.dao.EventAnnounceDAO;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.model.event_announce.EventAnnounce;
import com.aionemu.gameserver.model.event_announce.EventAnnounceType;

/**
 * @author zxl001
 */
public class MySQL5EventAnnounceDAO extends EventAnnounceDAO {

	@Override
	public boolean supports(String databaseName, int majorVersion, int minorVersion) {
		return MySQL5DAOUtils.supports(databaseName, majorVersion, minorVersion);
	}

	@Override
	public List<EventAnnounce> loadEventAnnounces() {
		final List<EventAnnounce> announces = new ArrayList<EventAnnounce>();
		DB.select("SELECT * FROM event_announce", new ReadStH() {

			@Override
			public void handleRead(ResultSet resultSet) throws SQLException {
				while (resultSet.next()) {
					int id = resultSet.getInt("id");
					EventAnnounceType type = EventAnnounceType.valueOf(resultSet.getString("announce_type"));
					int msg_id = resultSet.getInt("message_id");
					String txt = resultSet.getString("announce_txt");
					String cron = resultSet.getString("cron_txt");
					int world = resultSet.getInt("world_id");
					float x = resultSet.getFloat("x");
					float y = resultSet.getFloat("y");
					String zone = resultSet.getString("zone_name");
					EventAnnounce announce = new EventAnnounce(id, type, msg_id, txt, cron, world, x, y, zone);
					announces.add(announce);
				}
			}
		});
		return announces;
	}
}
