/*
 * This file is part of aion-unique <aion-unique.org>.
 *
 * aion-unique is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * aion-unique is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with aion-unique. If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.slf4j.LoggerFactory;

import org.slf4j.Logger;

import com.aionemu.commons.database.DB;
import com.aionemu.commons.database.DatabaseFactory;
import com.aionemu.commons.database.IUStH;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.dao.PlayerAppearanceDAO;
import com.aionemu.gameserver.model.gameobjects.player.PlayerAppearance;

/**
 * @author SoulKeeper, AEJTester, srx47
 */
public class MySQL5PlayerAppearanceDAO extends PlayerAppearanceDAO {

	private static final Logger log = LoggerFactory.getLogger(PlayerAppearanceDAO.class);

	/**
	 * {@inheritDoc}
	 */
	@Override
	public PlayerAppearance load(final int playerId) {
		Connection con = null;
		final PlayerAppearance pa = new PlayerAppearance();
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement statement = con.prepareStatement("SELECT * FROM player_appearance WHERE player_id = ?");
			statement.setInt(1, playerId);
			ResultSet resultSet = statement.executeQuery();
			if (resultSet.next()) {
				pa.setVoice(resultSet.getInt("voice"));
				pa.setSkinRGB(resultSet.getInt("skin_rgb"));
				pa.setHairRGB(resultSet.getInt("hair_rgb"));
				pa.setRightEyeRGB(resultSet.getInt("reye_rgb"));
				pa.setLipRGB(resultSet.getInt("lip_rgb"));
				pa.setFace(resultSet.getInt("face"));
				pa.setHair(resultSet.getInt("hair"));
				pa.setDeco(resultSet.getInt("deco"));
				pa.setTattoo(resultSet.getInt("tattoo"));
				pa.setUnk1(resultSet.getInt("unk1"));
				pa.setExpression(resultSet.getInt("expression"));
				pa.setEyeBall(resultSet.getInt("eyeball"));
				pa.setUnk2(resultSet.getInt("unk2"));
				pa.setLeftEyeRGB(resultSet.getInt("leye_rgb"));
				pa.setEyelash(resultSet.getInt("eyelash"));
				pa.setUnk3(resultSet.getInt("unk3"));
				pa.setFaceStyle(resultSet.getInt("face_style"));
				pa.setBrowShape(resultSet.getInt("brow_shape"));
				pa.setEyePosition(resultSet.getInt("eye_position"));
				pa.setEyeSpacing(resultSet.getInt("eye_spacing"));
				pa.setEyeLength(resultSet.getInt("eye_length"));
				pa.setEyeSize(resultSet.getInt("eye_size"));
				pa.setEyeStyle(resultSet.getInt("eye_style"));
				pa.setPupil(resultSet.getInt("pupil"));
				pa.setBrowPosition(resultSet.getInt("brow_position"));
				pa.setBrowAngle(resultSet.getInt("brow_angle"));
				pa.setBrowStyle(resultSet.getInt("brow_style"));
				pa.setNosePosition(resultSet.getInt("nose_position"));
				pa.setNoseBridge(resultSet.getInt("nose_bridge"));
				pa.setNostril(resultSet.getInt("nostril"));
				pa.setNose(resultSet.getInt("nose"));
				pa.setCheek(resultSet.getInt("cheek"));
				pa.setMouthPosition(resultSet.getInt("mouth_position"));
				pa.setMouthSize(resultSet.getInt("mouth_size"));
				pa.setLipThickness(resultSet.getInt("lip_thickness"));
				pa.setMouthSide(resultSet.getInt("mouth_side"));
				pa.setLipStyle(resultSet.getInt("lip_style"));
				pa.setJawPosition(resultSet.getInt("jaw_position"));
				pa.setUnk4(resultSet.getInt("unk4"));
				pa.setEarStyle(resultSet.getInt("ear_style"));
				pa.setHeadSize(resultSet.getInt("head_size"));
				pa.setNeckThickness(resultSet.getInt("neck_thickness"));
				pa.setNeckLength(resultSet.getInt("neck_length"));
				pa.setShoulders(resultSet.getInt("shoulders"));
				pa.setShanghaiWai(resultSet.getInt("shanghai_wai"));
				pa.setBust(resultSet.getInt("bust"));
				pa.setWaist(resultSet.getInt("waist"));
				pa.setHipLine(resultSet.getInt("hip_line"));
				pa.setUpArmThickness(resultSet.getInt("uparm_thickness"));
				pa.setPalmSize(resultSet.getInt("palm_size"));
				pa.setThighThickness(resultSet.getInt("thigh_thickness"));
				pa.setFootSize(resultSet.getInt("foot_size"));
				pa.setFacialRate(resultSet.getInt("facial_rate"));
				pa.setUnk5(resultSet.getInt("unk5"));
				pa.setArmLength(resultSet.getInt("arm_length"));
				pa.setLegLength(resultSet.getInt("leg_length"));
				pa.setShoulderWidth(resultSet.getInt("shoulder_width"));
				pa.setFaceAppearance(resultSet.getInt("face_appearance"));
				pa.setEyeballSize(resultSet.getInt("eyeball_size"));
				pa.setBodyLength(resultSet.getInt("body_length"));
				pa.setLowArmThickness(resultSet.getInt("lowarn_thickness"));
				pa.setHandLength(resultSet.getInt("hand_length"));
				pa.setCalfThickness(resultSet.getInt("calf_thickness"));
				pa.setHeight(resultSet.getFloat("height"));
			}
			resultSet.close();
			statement.close();
		}
		catch (Exception e) {
			log.error("Could not restore PlayerAppearance data for player " + playerId + " from DB: " + e.getMessage(), e);
			return null;
		}
		finally {
			DatabaseFactory.close(con);
		}
		return pa;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean store(final int id, final PlayerAppearance pa) {

		return DB
			.insertUpdate(
				"REPLACE INTO player_appearance ("
					+ "player_id, voice, skin_rgb, hair_rgb, reye_rgb, lip_rgb, face, hair, deco, tattoo, unk1, expression, eyeball,"
					+ "unk2, leye_rgb, eyelash, unk3, face_style, brow_shape, eye_position,"
					+ "eye_spacing, eye_length, eye_size, eye_style, pupil, brow_position, brow_angle, "
					+ "brow_style, nose_position, nose_bridge, nostril, nose, cheek, mouth_position, mouth_size, lip_thickness,"
					+ "mouth_side, lip_style, jaw_position, unk4, ear_style , head_size, neck_thickness, neck_length, shoulders, shanghai_wai, bust, waist,"
					+ "hip_line, uparm_thickness, palm_size, thigh_thickness, foot_size, facial_rate, unk5, arm_length, leg_length, shoulder_width, face_appearance, eyeball_size, body_length, lowarn_thickness, hand_length, calf_thickness, height)" + " VALUES "
					+ "(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?,"
					+ "?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?,?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?" + ")", new IUStH() {

					@Override
					public void handleInsertUpdate(PreparedStatement ps) throws SQLException {
						log.debug("[DAO: MySQL5PlayerAppearanceDAO] storing appereance " + id);
						ps.setInt(1, id);
						ps.setInt(2, pa.getVoice());
						ps.setInt(3, pa.getSkinRGB());
						ps.setInt(4, pa.getHairRGB());
						ps.setInt(5, pa.getRightEyeRGB());
						ps.setInt(6, pa.getLipRGB());
						ps.setInt(7, pa.getFace());
						ps.setInt(8, pa.getHair());
						ps.setInt(9, pa.getDeco());
						ps.setInt(10, pa.getTattoo());
						ps.setInt(11, pa.getUnk1());
						ps.setInt(12, pa.getExpression());
						ps.setInt(13, pa.getEyeBall());
						ps.setInt(14, pa.getUnk2());
						ps.setInt(15, pa.getLeftEyeRGB());
						ps.setInt(16, pa.getEyelash());
						ps.setInt(17, pa.getUnk3());
						ps.setInt(18, pa.getFacStyle());
						ps.setInt(19, pa.getBrowShape());
						ps.setInt(20, pa.getEyePosition());
						ps.setInt(21, pa.getEyeSpacing());
						ps.setInt(22, pa.getEyeLength());
						ps.setInt(23, pa.getEyeSize());
						ps.setInt(24, pa.getEyeStyle());
						ps.setInt(25, pa.getPupil());
						ps.setInt(26, pa.getBrowPosition());
						ps.setInt(27, pa.getBrowAngle());
						ps.setInt(28, pa.getBrowStyle());
						ps.setInt(29, pa.getNosePosition());
						ps.setInt(30, pa.getNoseBridge());
						ps.setInt(31, pa.getNostril());
						ps.setInt(32, pa.getNose());
						ps.setInt(33, pa.getCheek());
						ps.setInt(34, pa.getMouthPosition());
						ps.setInt(35, pa.getMouthSize());
						ps.setInt(36, pa.getLipThickness());
						ps.setInt(37, pa.getMouthSide());
						ps.setInt(38, pa.getLipStyle());
						ps.setInt(39, pa.getJawPosition());
						ps.setInt(40, pa.getUnk4());
						ps.setInt(41, pa.getEarStyle());
						ps.setInt(42, pa.getHeadSize());
						ps.setInt(43, pa.getNeckThickness());
						ps.setInt(44, pa.getNeckLength());
						ps.setInt(45, pa.getShoulders());
						ps.setInt(46, pa.getShanghaiWai());
						ps.setInt(47, pa.getBust());
						ps.setInt(48, pa.getWaist());
						ps.setInt(49, pa.getHipLine());
						ps.setInt(50, pa.getUpArmThickness());
						ps.setInt(51, pa.getPalmSize());
						ps.setInt(52, pa.getThighThickness());
						ps.setInt(53, pa.getFootSize());
						ps.setInt(54, pa.getFacialRate());
						ps.setInt(55, pa.getUnk5());
						ps.setInt(56, pa.getArmLength());
						ps.setInt(57, pa.getLegLength());
						ps.setInt(58, pa.getShoulderWidth());
						ps.setInt(59, pa.getFaceAppearance());
						ps.setInt(60, pa.getEyeballSize());
						ps.setInt(61, pa.getBodyLength());
						ps.setInt(62, pa.getLowArmThickness());
						ps.setInt(63, pa.getHandLength());
						ps.setInt(64, pa.getCalfThickness());
						ps.setFloat(65, pa.getHeight());
						ps.execute();
					}
				});
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean supports(String s, int i, int i1) {
		return MySQL5DAOUtils.supports(s, i, i1);
	}
}
