/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package mysql5;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;

import javolution.util.FastMap;

import com.aionemu.commons.database.DatabaseFactory;
import com.aionemu.gameserver.dao.MySQL5DAOUtils;
import com.aionemu.gameserver.dao.SkillSkinDAO;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_ATTACK_STATUS.LOG;

/**
 * @author 81002
 */
public class MySQL5SKillSkinDAO extends SkillSkinDAO {
	
	public static final String SELECT_QUERY = "SELECT `skin_id`, `skill_id` FROM `skill_skin` WHERE `object_id` = ?";
	public static final String INSERT_QUERY = "INSERT INTO `skill_skin` (`object_id`, `skin_id`, `skill_id`) VALUES (?,?,?)";
	public static final String UPDATE_QUERY = "UPDATE `skill_skin` SET `skill_id`=? WHERE `object_id`=? AND `skin_id`=?";
	
	@Override
	public boolean supports(String databaseName, int majorVersion, int minorVersion) {
		return MySQL5DAOUtils.supports(databaseName, majorVersion, minorVersion);
	}

	@Override
	public void loadSkillSkin(Player player) {
		Connection con = null;
		FastMap<Integer, String> skins = new FastMap<Integer, String>();
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement st = con.prepareStatement(SELECT_QUERY);
			st.setInt(1, player.getObjectId());
			ResultSet rs = st.executeQuery();
			while (rs.next()) {
				int skinid = rs.getInt("skin_id");
				String skillId = rs.getString("skill_id");
				skins.put(skinid, skillId);
			}
			rs.close();
			st.close();
		}
		catch (Exception e) {
			// TODO: handle exception
		}
		finally{
			DatabaseFactory.close(con);
		}
		player.getSkillSkinList().setSkillSkins(skins);
	}

	@Override
	public void addSkin(int objectId, int skinId) {
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement ps = con.prepareStatement(INSERT_QUERY);
			ps.setInt(1, objectId);
			ps.setInt(2, skinId);
			ps.setString(3, "");
			ps.execute();
			ps.close();
		}
		catch(Exception e) {
			System.out.print("\n" + e.toString() + "\n");
		}
		finally {
			DatabaseFactory.close(con);
		}
	}

	@Override
	public void updataUse(int objId, int id, String skillid) {
		Connection con = null;
		try {
			con = DatabaseFactory.getConnection();
			PreparedStatement ps = con.prepareStatement(UPDATE_QUERY);
			ps.setString(1, skillid);
			ps.setInt(2, objId);
			ps.setInt(3, id);
			ps.execute();
			ps.close();
		}
		catch (Exception e) {
			System.out.print("\n" + e.toString() + "\n");
		}
		finally {
			DatabaseFactory.close(con);
		}
	}
}
