/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package admincommands;

import java.io.File;
import java.io.FileOutputStream;
import java.util.Iterator;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.Document;

import com.aionemu.commons.network.util.ThreadPoolManager;
import com.aionemu.gameserver.dataholders.DataManager;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.templates.walker.RouteStep;
import com.aionemu.gameserver.model.templates.walker.WalkerTemplate;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.chathandlers.AdminCommand;

/**
 * @author zxl001
 */
public class FixWalker extends AdminCommand {

	public FixWalker() {
		super("fixw");
	}

	private Iterator<RouteStep> ros;
	private String walkerId;

	@Override
	public void execute(Player player, String... params) {
		if (params.length < 1) {
			onFail(player, null);
		}

		walkerId = params[0];
		WalkerTemplate template;
		try {
			template = DataManager.WALKER_DATA.getWalkerTemplate(walkerId);
			DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
			DocumentBuilder builder = factory.newDocumentBuilder();
			Document document = builder.newDocument();
			org.w3c.dom.Element root = document.createElement("npc_walker");
			document.appendChild(root);
			org.w3c.dom.Element walker = document.createElement("walker_template");
			root.appendChild(walker);
			walker.setAttribute("route_id", walkerId);
			walker.setAttribute("pool", "1");
			ros = template.getRouteSteps().iterator();
			fixz(player, document, walker);
		}
		catch (Exception e) {
			PacketSendUtility.sendMessage(player, "not exits walker template");
		}
		finally {
		}
	}

	private void fixz(final Player player, final Document document, final org.w3c.dom.Element walker) {
		final RouteStep rs = ros.next();
		TeleportService2.teleportTo(player, player.getWorldId(), rs.getX(), rs.getY(), rs.getZ());
		ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				float z = player.getZ();
				org.w3c.dom.Element step = document.createElement("routestep");
				step.setAttribute("step", String.valueOf(rs.getRouteStep()));
				step.setAttribute("x", String.valueOf(rs.getX()));
				step.setAttribute("y", String.valueOf(rs.getY()));
				step.setAttribute("z", String.valueOf(z));
				PacketSendUtility.sendMessage(player, "z: " + z + " " + rs.getRouteStep());
				walker.appendChild(step);
				if (ros.hasNext())
					fixz(player, document, walker);
				else
					saveNewWalker(document);
			}
		}, 3000);
	}
	
	private void saveNewWalker(Document document) {
		try {
				TransformerFactory transFactory = TransformerFactory.newInstance();
				Transformer transFormer = transFactory.newTransformer();
				DOMSource domSource = new DOMSource(document);
				File file = new File("data/static_data/npc_walker/" + walkerId + ".xml");
				if (!file.exists()) {
					file.createNewFile();
				}
				FileOutputStream out = new FileOutputStream(file);
				StreamResult xmlResult = new StreamResult(out);
				transFormer.transform(domSource, xmlResult);
				out.close();
		}
		catch (Exception e) {
		}
	}

	@Override
	public void onFail(Player player, String message) {

	}
}
