/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.custom;

import java.util.List;

import ai.GeneralNpcAI2;

import com.aionemu.commons.utils.Rnd;
import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.PersistentState;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.templates.item.ArmorType;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIALOG_WINDOW;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.services.BreachService;
import com.aionemu.gameserver.services.item.ItemPacketService;
import com.aionemu.gameserver.utils.PacketSendUtility;

/**
 * @author zxl001
 */
@AIName("breach_fun")
public class BreachFunAI2 extends GeneralNpcAI2 {
	
	private static final int[] WeaponSkills = new int[] { 13001, 13002, 13003, 13004, 13005, 13006, 13007, 13008, 13009, 13010, 13011, 13012, 13013, 13014, 13015, 13016, 13017,
		13018, 13019, 13020, 13021, 13022, 13023, 13024, 13025, 13026, 13027, 13028, 13029, 13030, 13031, 13032, 13033, 13034, 13035, 13036, 13037 };

	private static final int[] ArmorSkills = new int[] { 13038, 13039, 13040, 13041, 13042, 13043, 13044, 13045, 13046, 13047, 13048, 13049, 13050, 13051, 13052, 13053, 13054,
		13055, 13056, 13057, 13058, 13059, 13060, 13061, 13062, 13063, 13064, 13065, 13066, 13067, 13068, 13069, 13070, 13071, 13072, 13073, 13074, 13075, 13076, 13077, 13078, 13079,
		13080, 13081, 13082, 13083, 13084, 13085, 13086, 13087, 13088, 13089, 13090, 13091, 13092, 13093, 13094, 13095, 13096, 13097, 13098, 13099, 13100, 13101, 13102, 13103, 13108,
		13109, 13110, 13111, 13112, 13113, 13114, 13115, 13116, 13117, 13118, 13119, 13120, 13121, 13122, 13123, 13124, 13125, 13126, 13127, 13128, 13129, 13130, 13131, 13132, 13133,
		13134, 13135, 13136, 13137, 13138, 13139, 13140, 13141, 13142, 13143, 13144, 13145, 13146, 13147 };

	@Override
	protected void handleDialogStart(Player player) {
		PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 10));
	}

	@Override
	public boolean onDialogSelect(Player player, int dialogId, int lastPage, int questId, int extendedRewardIndex) {
		Item item = null;
		switch (lastPage) {
			case 1011:
			case 1693:
			case 2375:
				switch (dialogId) {
					case 10000:
						item = player.getEquipment().getMainHandWeapon();
						if (item == null)
							item = player.getEquipment().getComboWeapon();
						break;
					case 10001:
						item = player.getEquipment().getOffHandWeapon();
						break;
					case 10002:
						item = player.getEquipment().getTorsoItem();
						break;
					case 10003:
						item = player.getEquipment().getShoulderItem();
						break;
					case 10004:
						item = player.getEquipment().getPantsItem();
						break;
					case 10005:
						item = player.getEquipment().getGlovesItem();
						break;
					case 10006:
						item = player.getEquipment().getBootsItem();
						break;
					case 10007:
						item = player.getEquipment().getWingItem();
						break;
					default:
						PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), dialogId));
						return true;
				}
				if (lastPage == 1011)
					return Modificationskills(player, item);
				else if (lastPage == 1693)
					return AdvEnchant(player, item);
				else if (lastPage == 2375)
					return Acthorze(player, item, 2377, 2376);
				break;
			case 2034:
				switch (dialogId) {
					case 10000:
						item = player.getEquipment().getFeatherItem();
						break;
					case 10001:
						item = player.getEquipment().getHelmetItem();
						break;
					case 10002:
						item = player.getEquipment().getNecklaceItem();
						break;
					case 10003:
						item = player.getEquipment().getLeftEarringsItem();
						break;
					case 10004:
						item = player.getEquipment().getRightEarringsItem();
						break;
					case 10005:
						item = player.getEquipment().getLeftRingItem();
						break;
					case 10006:
						item = player.getEquipment().getRightRingItem();
						break;
					case 10007:
						item = player.getEquipment().getWingItem();
						break;
					default:
						PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), dialogId));
						return true;
				}
				return Acthorze(player, item, 2036, 2035);
			case 2716:
			case 2717:
				switch(dialogId) {
					case 10000:
						return StigmaEnchant(player, lastPage);
				}
				break;
			default:
				PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), dialogId));
				return true;
		}
		return false;
	}
	
	// 洗练突破技能
	boolean Modificationskills(Player player, Item item) {
		
		if (player.getInventory().getItemCountByItemId(186000230) < 1000) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 4762));
			return true;
		}
		
		if (item != null && (item.getEnchantLevel() >= 20 || item.getAuthorize() >= 20)) {
			BreachService.onItemUnequipment(item, player);
			int index = 0;
			int skillId = 0;
			if (item.getItemTemplate().isWeapon()) {
				index = Rnd.get(WeaponSkills.length);
				skillId = WeaponSkills[index];
			}
			else {
				index = Rnd.get(ArmorSkills.length);
				skillId = ArmorSkills[index];
			}
			item.setEnchantSkillId(skillId);
			player.getEquipment().setPersistentState(PersistentState.UPDATE_REQUIRED);
			BreachService.onItemEquipment(item, player);
			ItemPacketService.updateItemAfterInfoChange(player, item);
			player.getInventory().decreaseByItemId(186000230, 1000);
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1352));
			return true;
		}
		PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1012));
		return true;
	}
	
	// 主神强化
	boolean AdvEnchant(Player player, Item item) {
		if (item == null) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1694));
			return true;
		}
		if (item.getEnchantLevel() >= 20) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1696));
			return true;
		}
		
		int count = (20 - item.getEnchantLevel()) * 10000;
		
		if (player.getInventory().getItemCountByItemId(186000230) < count) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 4762));
			return true;
		}
		
		if (item != null && item.getEnchantLevel() >= 15) {
			item.setEnchantLevel(20);
			player.getEquipment().setPersistentState(PersistentState.UPDATE_REQUIRED);
			BreachService.setItemSkill(player, item, true);
			player.getGameStats().updateStatsVisually();
			player.getInventory().decreaseByItemId(186000230, count);
			ItemPacketService.updateItemAfterInfoChange(player, item);
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1695));
			return true;
		}
		return true;
	}
	
	// 首饰觉醒
	boolean Acthorze(Player player, Item item, int succ, int fial) {
		if (item == null) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), fial));
			return true;
		}
		
		int maxLevel = item.getItemTemplate().getAuthorize();
		
		// 控制羽毛最大觉醒等级为10级
		if (item.getItemTemplate().getArmorType() == ArmorType.FEATHER) {
			if (maxLevel > 10)
				maxLevel = 10;
		}
		else {
			if (maxLevel > 20)
				maxLevel = 20;
		}
		
		if (item.getAuthorize() >= maxLevel) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), fial));
			return true;
		}
		
		int price = getPrice(item);
		
		if (player.getInventory().getItemCountByItemId(186000230) < price) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 4762));
			return true;
		}
		
		player.getInventory().decreaseByItemId(186000230, price);
		item.setAuthorize(maxLevel);
		player.getEquipment().setPersistentState(PersistentState.UPDATE_REQUIRED);
		player.getGameStats().updateStatsVisually();
		ItemPacketService.updateItemAfterInfoChange(player, item);
		PacketSendUtility.sendPacket(player, SM_SYSTEM_MESSAGE.STR_MSG_ITEM_AUTHORIZE_SUCCEEDED(item.getNameID(), item.getAuthorize()));
		PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), succ));
		return true;
	}
	
	boolean StigmaEnchant(Player player, int lastPage) {
		
		List<Item> stigmas = player.getEquipment().getEquippedItemsAllStigma();
		
		if (stigmas.size() == 0)
			return true;
		
		// 当前最低强化等级
		int minLevel = 0;
		// 强化后等级
		int enchantLevel = 5;
		// 强化时消耗的物品ID
		int itemID = 186000230;
		// 消耗数量
		int count = 10000;
		//=======================================
		int min = 0, max = 0;
		if (lastPage == 2716) {
			for(Item item : stigmas) {
				int level = item.getEnchantLevel();
				if (level < minLevel) {
					min++;
					continue;
				}
				if (level >= enchantLevel) {
					max++;
					continue;
				}
			}
			if (min > 0) {
				PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 2717));
				return true;
			}
			if (max == stigmas.size()) {
				PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 2721));
				return true;
			}
		}
		
		if (player.getInventory().getItemCountByItemId(itemID) < count) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 2718));
			return true;
		}
		
	  for(Item item : stigmas) {
	  	if (item.getItemTemplate().isNoEnchant())
	  		continue;
	  	
			int level = item.getEnchantLevel();
			if (level >= minLevel && level < enchantLevel) {
				item.setEnchantLevel(enchantLevel);
				ItemPacketService.updateItemAfterInfoChange(player, item);
			}
		}
	  player.getEquipment().setPersistentState(PersistentState.UPDATE_REQUIRED);
	  player.getInventory().decreaseByItemId(itemID, count);
	  PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 2719));
		return true;
	}
	
	int getPrice(Item item) {
		if (item.getItemTemplate().isAccessory())
			return 500;//首饰觉醒价格
		if (item.getItemTemplate().isArmor())
			return 500;//防具觉醒价格
		if (item.getItemTemplate().isWeapon())
			return 500;//武器觉醒价格
		return 500;
	}
}
