/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.custom;

import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.PersistentState;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIALOG_WINDOW;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.services.item.ItemPacketService;
import com.aionemu.gameserver.utils.PacketSendUtility;

import ai.GeneralNpcAI2;

/**
 * @author zxl001
 */
@AIName("custom_acthorize")
public class CustomActhorizeAI2 extends GeneralNpcAI2 {

	@Override
	protected void handleDialogStart(Player player) {
		PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 10));
	}
	
	@Override
	public boolean onDialogSelect(Player player, int dialogId, int lastPage, int questId, int extendedRewardIndex) {
		if (dialogId == 10000)
			return Acthorze(player);
		return true;
	}
	
	boolean Acthorze(Player player) {
		
		int minLevel = 0;
		int toLevel = 5;
		int price = 1000;
		
		switch(getNpcId()) {
			case 820821:
				minLevel = 5;
				toLevel = 10;
				price = 20000;
				break;
			case 820822:
				minLevel = 10;
				toLevel = 15;
				price = 88888;
				break;
		}
		
		if (player.getInventory().getItemCountByItemId(186000094) < price) {
			PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 4762));
			return true;
		}
		
		for(Item item : player.getEquipment().getEquippedItemsWithoutStigma()) {
			int maxLevel = item.getItemTemplate().getAuthorize();
			if (maxLevel == 0)
				continue;
			if (item.getAuthorize() < minLevel || item.getAuthorize() > toLevel)
				continue;
			
			if (toLevel > maxLevel)
				item.setAuthorize(maxLevel);
			else 
				item.setAuthorize(toLevel);
			ItemPacketService.updateItemAfterInfoChange(player, item);
			PacketSendUtility.sendPacket(player, SM_SYSTEM_MESSAGE.STR_MSG_ITEM_AUTHORIZE_SUCCEEDED(item.getNameID(), item.getAuthorize()));
		}
		player.getInventory().decreaseByItemId(186000094, price);
		player.getEquipment().setPersistentState(PersistentState.UPDATE_REQUIRED);
		player.getGameStats().updateStatsVisually();
		PacketSendUtility.sendPacket(player, new SM_DIALOG_WINDOW(getObjectId(), 1011));
		return true;
	}
}
