/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.custom;

import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.model.Race;
import com.aionemu.gameserver.model.gameobjects.LetterType;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.services.mail.SystemMailService;
import com.aionemu.gameserver.world.World;
import com.aionemu.gameserver.world.knownlist.Visitor;

import ai.AggressiveNpcAI2;

/**
 * @author zxl001
 */
@AIName("custom_boss2")
public class CustomBoss2AI2 extends AggressiveNpcAI2 {

	private Race attackRace;
	private Race defendRace;
	
	//
	private String a_sender = "ʼ";
	private int a_itemId = 00000000;
	private int a_count = 0;
	private String a_title = "ʼ";
	private String a_message = "ʼ";
	
	//ط
	private String d_sender = "ʼ";
	private int d_itemId = 00000000;
	private int d_count = 0;
	private String d_title = "ʼ";
	private String d_message = "ʼ";

	@Override
	protected void handleSpawned() {
		switch (getNpcId()) {
			case 100000:
				attackRace = Race.ASMODIANS;
				defendRace = Race.ELYOS;
				break;
			case 200000:
				attackRace = Race.ELYOS;
				defendRace = Race.ASMODIANS;
				break;
		}
		super.handleSpawned();
	}

	@Override
	protected void handleDespawned() {
		if (!getOwner().getLifeStats().isAlreadyDead()) {
			World.getInstance().getWorldMap(getOwner().getWorldId()).getWorldMapInstance().doOnAllPlayers(new Visitor<Player>() {

				@Override
				public void visit(Player object) {
					if (object.getRace().getRaceId() == defendRace.getRaceId()) {
						SystemMailService.getInstance().sendMail(d_sender, object.getName(), d_title, d_message, d_itemId, d_count, 0, LetterType.NORMAL);
					}
				}
			});
		}
		super.handleDespawned();
	}

	@Override
	protected void handleDied() {
		World.getInstance().getWorldMap(getOwner().getWorldId()).getWorldMapInstance().doOnAllPlayers(new Visitor<Player>() {

			@Override
			public void visit(Player object) {
				if (object.getRace().getRaceId() == attackRace.getRaceId()) {
					SystemMailService.getInstance().sendMail(a_sender, object.getName(), a_title, a_message, a_itemId, a_count, 0, LetterType.NORMAL);
				}
			}
		});
		super.handleDied();
	}
}
