/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.custom;

import static ch.lambdaj.Lambda.maxFrom;

import java.util.Collection;
import java.util.HashSet;

import com.aionemu.gameserver.ai2.AI2Actions;
import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.dataholders.DataManager;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.gameobjects.state.CreatureState;
import com.aionemu.gameserver.model.templates.chest.ChestTemplate;
import com.aionemu.gameserver.services.custom.EventBoxService;
import com.aionemu.gameserver.services.custom.EventType;
import com.aionemu.gameserver.services.custom.PlayerEvent;
import com.aionemu.gameserver.services.drop.DropRegistrationService;
import com.aionemu.gameserver.services.drop.DropService;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.audit.AuditLogger;

import ai.ActionItemNpcAI2;

/**
 * @author zxl001
 */
@AIName("customchest")
public class CustomBoxAI2 extends ActionItemNpcAI2 {

	private ChestTemplate chestTemplate;

	@Override
	protected void handleDialogStart(final Player player) {
		chestTemplate = DataManager.CHEST_DATA.getChestTemplate(getNpcId());

		if (chestTemplate == null) {
			return;
		}
		super.handleDialogStart(player);
	}
	
	@Override
	protected void handleUseItemFinish(Player player) {
			if (getOwner().isInState(CreatureState.DEAD)) {
				AuditLogger.info(player, "Attempted multiple Chest looting!");
				return;
			}
			
			PlayerEvent event = player.getEventInfo().getPlayerEvent(EventType.Event_Box);
			if (event == null)
				return;
			
			if (event.getUseCount() >= 25) {
				PacketSendUtility.sendMessage(player, "[͸] Ѵﵽ");
				return;
			}
			else {
				event.addUseCount();
				PacketSendUtility.sendMessage(player, "[͸] ѿ " + event.getUseCount() + "/25");
			}
			
			AI2Actions.dieSilently(this, player);
			Collection<Player> players = new HashSet<Player>();
			players.add(player);
			DropRegistrationService.getInstance().registerDrop(getOwner(), player, maxFrom(players).getLevel(), players);
			DropService.getInstance().requestDropList(player, getObjectId());
			super.handleUseItemFinish(player);
	}
	
	@Override
	protected void handleDialogFinish(Player player) {
	}
}
