/*
 * This file is part of Aion-Finish <Aion-Finish.org>
 *
 * Aion-Finish is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Aion-Finish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Aion-Finish. If not, see <http://www.gnu.org/licenses/>.
 */
package ai.instance.SteelRoseQuarters;

import ai.ActionItemNpcAI2;

import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.skillengine.SkillEngine;
import com.aionemu.gameserver.utils.MathUtil;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldPosition;
import com.aionemu.gameserver.world.knownlist.Visitor;

/**
 * Author zxl001
 **/
@AIName("rosedeckmobilecannon")
public class RoseCargoDeckMobileCannonAI2 extends ActionItemNpcAI2 {
	
	private int attackCount = 0;
	
	@Override
	protected void handleUseItemFinish(final Player player) {
		WorldPosition worldPosition = player.getPosition();
		if (worldPosition.isInstanceMap()) {
			if (worldPosition.getMapId() == 301050000) {
				if (attackCount >= 2) {
					PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(true, 1401295, 0, 26));
					return;
				}
				Npc targetNpc = null;
				switch (getOwner().getNpcId()) {
					case 730788:
						targetNpc = (Npc)spawn(230702, 524.16547f, 511.43613f, 1023.2001f, (byte) 5);
						break;
					case 730794:
						targetNpc = (Npc)spawn(230702, 527.1333f, 503.94174f, 1023.20184f, (byte) 90);
						break;
					case 730772:
						targetNpc = (Npc)spawn(230702, 594.45886f, 550.9459f, 1021.79736f, (byte) 66);
						break;
					case 730785:
						targetNpc = (Npc)spawn(230702, 570.13385f, 490.98996f, 1023.52985f, (byte) 59);
						break;
					case 730792:
						targetNpc = (Npc)spawn(230702, 573.51184f, 546.8365f, 1022.0157f, (byte) 27);
						break;
				}
				
				getOwner().setTarget(targetNpc);
				
				SkillEngine.getInstance().getSkill(getOwner(), 20385, 55, getOwner()).useNoAnimationSkill();
				
				final Npc npc = targetNpc;

				ThreadPoolManager.getInstance().schedule(new Runnable() {
					
					@Override
					public void run() {
						onAttackNpc(player, npc);
					}
				}, getOwner().getCastingSkill().getSkillTemplate().getDuration());
				
				attackCount++;
			}
		}
	}
	
	private void onAttackNpc(final Player player, final Npc npc) {
		
		npc.getKnownList().doOnAllNpcs(new Visitor<Npc>() {
			
			@Override
			public void visit(Npc object) {
				if (MathUtil.isInRange(npc, object, 7))
					object.getController().onAttack(player, object.getLifeStats().getMaxHp() + 1, true);
			}
		});
		npc.getController().onAttack(player, npc.getLifeStats().getMaxHp() + 1, true);
	}
}