/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package ai.instance.luna;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import ai.AggressiveNpcAI2;

import com.aionemu.commons.utils.Rnd;
import com.aionemu.gameserver.ai2.AIName;
import com.aionemu.gameserver.model.gameobjects.Creature;

/**
 * @author 81002
 */
@AIName("luna_mads")
public class LunaBossMad99s extends AggressiveNpcAI2 {

	private List<Integer> percents = new ArrayList<Integer>();

	@Override
	protected void handleAttack(Creature creature) {
		super.handleAttack(creature);
		checkHp(getOwner().getLifeStats().getHpPercentage());
	}

	@Override
	protected void handleDespawned() {
		if (percents.size() != 9) {
			percents.clear();
			Collections.addAll(percents, new Integer[] {10,20,30,40,50,60,70,80,90});
		}
		super.handleDespawned();
	}

	@Override
	protected void handleDied() {
		super.handleDied();
		percents.clear();
		diespawn();
	}

	/**
	 * @param hpPercentage
	 */
	private synchronized void checkHp(int hpPercentage) {
		for (Integer hpInteger : percents) {
			if (hpInteger >= hpPercentage) {
				percents.remove(hpInteger);
				spawngroup();
			}
		}
	}

	private void diespawn() {
		float x1 = getOwner().getX();
		float y1 = getOwner().getY();
		float z1 = getOwner().getZ();
		spawn(246159, x1, y1, z1, (byte) 0);
		for (int i = 0; i < 20; i++) {
			float x = getOwner().getX() + Rnd.get(-3, 3);
			float y = getOwner().getY() + Rnd.get(-3, 1);
			float z = getOwner().getZ();
			spawn(246356, x, y, z, (byte) 0);
		}
	}

	private void spawngroup() {
		for (int i = 0; i < 4; i++) {
			float x = getOwner().getX() + Rnd.get();
			float y = getOwner().getX() + Rnd.get();
			float z = getOwner().getZ();
			spawn(246174, x, y, z, (byte) 0);
		}
	}
}
