/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.Future;

import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.EmotionType;
import com.aionemu.gameserver.model.Race;
import com.aionemu.gameserver.model.gameobjects.Creature;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_EMOTION;
import com.aionemu.gameserver.network.aion.serverpackets.SM_QUEST_ACTION;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;

/**
 * @author zxl001
 */
@InstanceID(MapID = 301270000, InstanceMaskID = 0)
public class BarunaDimensionalLabInstance extends GeneralInstanceHandler {

	private boolean isStart = false;
	private Future<?> instanceTimer;
	private List<Integer> boss = null;
	private boolean createEnd = false;

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		if (boss == null) {
			boss = new ArrayList<Integer>();
			boss.add(233898);
			boss.add(234990);
			boss.add(234991);
		}
	}
	
	@Override
	public void onEnterInstance(Player player) {
		if (createEnd)
			return;
		
		if (player.getRace() == Race.ASMODIANS) {
			spawn(855088, 226.76f, 256.77f, 312.577f, (byte)0);
			spawn(206362, 348.01f, 252.14f, 311.361f, (byte)15);
		}
		else {
			spawn(855087, 226.76f, 256.77f, 312.577f, (byte)0);
			spawn(206361, 348.01f, 252.14f, 311.361f, (byte)15);
		}
		createEnd = true;
	}

	@Override
	public void onDie(Npc npc) {
		switch (npc.getNpcId()) {
			case 233898:
			case 234990:
			case 234991:
				spawn(702389, 226.6172f, 260.147827f, 312.579926f, (byte) 0);
				break;
		}
	}

	@Override
	public void handleUseItemFinish(Player player, Npc npc) {
		super.handleUseItemFinish(player, npc);
		switch (npc.getNpcId()) {
			case 804578:
				if (!isStart)
					startTimeTask(player);
			case 234193:
				npc.getController().die();
				break;
		}
	}

	private void deleteNpc(Player player) {
		List<Npc> npcs = instance.getNpcs();
		for (Npc npc : npcs) {
			if (boss.contains(npc.getNpcId()))
				continue;
			if (player.isEnemyFrom(npc))
				npc.getController().delete();
		}
	}

	@Override
	public void onInstanceDestroy() {
		if (instanceTimer != null && !instanceTimer.isDone())
			instanceTimer.cancel(true);
	}

	@Override
	public void onExitInstance(Player player) {
		TeleportService2.moveToInstanceExit(player, mapId, player.getRace());
	}

	private void startTimeTask(final Player player) {
		PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402453));
		instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402454));
				instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

					@Override
					public void run() {
						PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402455));
						instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

							@Override
							public void run() {
								PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402456));
								instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

									@Override
									public void run() {
										PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402457));
										instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

											@Override
											public void run() {
												PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402458));
												PacketSendUtility.sendPacket(player, new SM_QUEST_ACTION(0, 60));
												instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

													@Override
													public void run() {
														PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1402461));
														deleteNpc(player);
													}
												}, 1 * 60 * 1000);
											}
										}, 2 * 60 * 1000);
									}
								}, 2 * 60 * 1000);
							}
						}, 5 * 60 * 1000);
					}
				}, 5 * 60 * 1000);
			}
		}, 5 * 60 * 1000);
	}

	@Override
	public boolean onDie(final Player player, Creature lastAttacker) {
		PacketSendUtility.broadcastPacket(player, new SM_EMOTION(player, EmotionType.DIE, 0, player.equals(lastAttacker) ? 0 : lastAttacker.getObjectId()), true);
		PacketSendUtility.sendPacket(player, new SM_DIE(player.haveSelfRezEffect(), player.haveSelfRezItem(), 0, 8));
		return true;
	}
}
