/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.aionemu.commons.network.util.ThreadPoolManager;
import com.aionemu.commons.utils.Rnd;
import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.drop.DropItem;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_PLAY_MOVIE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_QUEST_ACTION;
import com.aionemu.gameserver.services.drop.DropRegistrationService;
import com.aionemu.gameserver.services.item.ItemService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.world.WorldMapInstance;
import com.aionemu.gameserver.world.zone.ZoneInstance;
import com.aionemu.gameserver.world.zone.ZoneName;

/**
 * @author Ranastic
 */
@InstanceID(MapID = 301140000, InstanceMaskID = 336)
public class Danuar_Sanctuary extends GeneralInstanceHandler {

	private int danuarSanctuaryBossEasy;
	private int danuarSanctuaryBossMiddle;
	private int danuarSanctuaryBossStrong;
	private boolean isStartTimer1 = false;
	private boolean isStartTimer2 = false;
	private boolean isStartTimer3 = false;
	private Map<Integer, StaticDoor> doors;
	private List<Integer> movies = new ArrayList<Integer>();

	@Override
	public void onEnterInstance(Player player) {
		if (movies.contains(500)) {
			return;
		}
		doors = instance.getDoors();
		sendMovie(player, 500);
		openDoor(10);
		openDoor(154);
		openDoor(159);
		openDoor(160);
		openDoor(177);
		openDoor(202);
		openDoor(319);
		openDoor(350);
		openDoor(400);
		openDoor(430);
		openDoor(467);
		openDoor(689);
		openDoor(690);
		openDoor(691);
		openDoor(1530);
	}

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		int rnd = Rnd.get(1, 3);
		switch (rnd) {
			case 1:
				spawn(233086, 1056.5698f, 693.86584f, 282.0391f, (byte) 30); // Warmage Suyaroka.
				spawn(233089, 1045.4534f, 682.2679f, 282.0391f, (byte) 60); // Chief Medic Tagnu.
				spawn(233090, 1056.4889f, 670.9826f, 282.0391f, (byte) 91); // Virulent Ukahim.
				break;
			case 2:
				spawn(233380, 1045.4534f, 682.2679f, 282.0391f, (byte) 60); // Warmage Suyaroka.
				spawn(233381, 1056.4889f, 670.9826f, 282.0391f, (byte) 91); // Chief Medic Tagnu.
				spawn(233382, 1056.5698f, 693.86584f, 282.0391f, (byte) 30); // Virulent Ukahim.
				break;
			case 3:
				spawn(233383, 1045.4534f, 682.2679f, 282.0391f, (byte) 60); // Warmage Suyaroka.
				spawn(233384, 1056.4889f, 670.9826f, 282.0391f, (byte) 91); // Chief Medic Tagnu.
				spawn(233385, 1056.5698f, 693.86584f, 282.0391f, (byte) 30); // Virulent Ukahim.
				break;
		}
	}

	@Override
	public void handleUseItemFinish(Player player, Npc npc) {
		switch (npc.getNpcId()) {
			case 701859: // Metallic Mystic KeyStone.
				despawnNpc(npc);
				ItemService.addItem(player, 182400001, 10);
				break;
			case 701860: // Golden Mystic KeyStone.
				despawnNpc(npc);
				ItemService.addItem(player, 182400001, 10);
				break;
			case 701861: // Bronze Mystic KeyStone.
				despawnNpc(npc);
				ItemService.addItem(player, 182400001, 10);
				break;
			case 701862: // Cubic Mystic KeyStone.
				openDoor(0);
				despawnNpc(npc);
				break;
			case 701863: // Spherical Mystic KeyStone.
				openDoor(0);
				despawnNpc(npc);
				break;
			case 701864: // Pyramidal Mystic KeyStone.
				openDoor(0);
				despawnNpc(npc);
				break;
		}
	}

	@Override
	public void onDie(Npc npc) {
		Player player = npc.getAggroList().getMostPlayerDamage();
		switch (npc.getObjectTemplate().getTemplateId()) {
			case 233187: // Attack the rocks to activate the updraft.
				despawnNpc(npc);
				TeleportService2.teleportTo(player, 301140000, 887.1296f, 845.2534f, 292.86874f, (byte) 112, TeleportAnimation.BEAM_ANIMATION);
				break;
			case 233086: // Warmage Suyaroka.
			case 233089: // Chief Medic Tagnu.
			case 233090: // Virulent Ukahim.
				danuarSanctuaryBossEasy++;
				if (danuarSanctuaryBossEasy == 3) {
					spawn(701876, 1075.5334f, 682.4891f, 282.0391f, (byte) 60); // Danuar Sanctuary Exit.
				}
				break;
			case 233380: // Warmage Suyaroka.
			case 233381: // Chief Medic Tagnu.
			case 233382: // Virulent Ukahim.
				danuarSanctuaryBossMiddle++;
				if (danuarSanctuaryBossMiddle == 3) {
					spawn(701876, 1075.5334f, 682.4891f, 282.0391f, (byte) 60); // Danuar Sanctuary Exit.
				}
				break;
			case 233383: // Warmage Suyaroka.
			case 233384: // Chief Medic Tagnu.
			case 233385: // Virulent Ukahim.
				danuarSanctuaryBossStrong++;
				if (danuarSanctuaryBossStrong == 3) {
					spawn(701876, 1075.5334f, 682.4891f, 282.0391f, (byte) 60); // Danuar Sanctuary Exit.
				}
				break;
		}
	}

	// The players have 15 minutes to clear the way.
	// After 15 min boss "ELITE" will be removed.
	@Override
	public void onEnterZone(Player player, ZoneInstance zone) {
		if (zone.getAreaTemplate().getZoneName() == ZoneName.get("A_301140000")) {
			if (!isStartTimer1) {
				isStartTimer1 = true;
				System.currentTimeMillis();
				PacketSendUtility.sendPacket(player, new SM_QUEST_ACTION(0, 900));
				final Npc mobwaypath1A = (Npc) spawn(233391, 1050.2266f, 276.24228f, 309.3889f, (byte) 64);
				ThreadPoolManager.getInstance().schedule(new Runnable() {

					@Override
					public void run() {
						mobwaypath1A.getController().delete();
					}
				}, 900000);
			}
		}
		else if (zone.getAreaTemplate().getZoneName() == ZoneName.get("B_301140000")) {
			if (!isStartTimer2) {
				isStartTimer2 = true;
				System.currentTimeMillis();
				PacketSendUtility.sendPacket(player, new SM_QUEST_ACTION(0, 900));
				final Npc mobwaypath1B = (Npc) spawn(233391, 717.85614f, 980.1326f, 318.71698f, (byte) 110);
				ThreadPoolManager.getInstance().schedule(new Runnable() {

					@Override
					public void run() {
						mobwaypath1B.getController().delete();
					}
				}, 900000);
			}
		}
		else if (zone.getAreaTemplate().getZoneName() == ZoneName.get("C_301140000")) {
			if (!isStartTimer3) {
				isStartTimer3 = true;
				System.currentTimeMillis();
				PacketSendUtility.sendPacket(player, new SM_QUEST_ACTION(0, 900));
				final Npc mobwaypath1C = (Npc) spawn(233391, 1005.93787f, 1366.8308f, 337.25f, (byte) 13);
				ThreadPoolManager.getInstance().schedule(new Runnable() {

					@Override
					public void run() {
						mobwaypath1C.getController().delete();
					}
				}, 900000);
			}
		}
	}

	@Override
	public void onDropRegistered(Npc npc) {
		Set<DropItem> dropItems = DropRegistrationService.getInstance().geCurrentDropMap().get(npc.getObjectId());
		int npcId = npc.getNpcId();
		switch (npcId) {
			case 233391: // Danuar Sanctuary Chest.
				dropItems.add(DropRegistrationService.getInstance().regDropItem(1, 0, npcId, 185000181, 1));
				dropItems.add(DropRegistrationService.getInstance().regDropItem(1, 0, npcId, 185000182, 1));
				dropItems.add(DropRegistrationService.getInstance().regDropItem(1, 0, npcId, 185000183, 1));
				break;
		}
	}

	private void sendMovie(Player player, int movie) {
		if (!movies.contains(movie)) {
			movies.add(movie);
			PacketSendUtility.sendPacket(player, new SM_PLAY_MOVIE(0, movie));
		}
	}

	private void despawnNpc(Npc npc) {
		if (npc != null) {
			npc.getController().onDelete();
		}
	}

	private void openDoor(int doorId) {
		StaticDoor door = doors.get(doorId);
		if (door != null) {
			door.setOpen(true);
		}
	}
}
