/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance;

import java.util.List;
import java.util.Map;
import java.util.concurrent.Future;

import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.instance.InstanceScoreType;
import com.aionemu.gameserver.model.instance.instancereward.LunaInstanceReward;
import com.aionemu.gameserver.network.aion.serverpackets.SM_INSTANCE_SCORE;
import com.aionemu.gameserver.services.instance.InstanceService;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;
import com.aionemu.gameserver.world.knownlist.Visitor;

/**
 * @author 81002
 */
@InstanceID(MapID = 302100000, InstanceMaskID = 0)
public class Instance_302100000 extends GeneralInstanceHandler {

	private Future<?> instanceTimer;
	private long startTime;
	private Map<Integer, StaticDoor> doors;
	private LunaInstanceReward instanceReward;

	@Override
	public void onDie(Npc npc) {
		int npcId = npc.getNpcId();
		int titleid = npc.getObjectTemplate().getTitleId();
		int point = 0;
		switch (titleid) {
			case 2306179:
				point = 250;
				break;
			case 2306180:
				point = 550;
				break;
			case 2306181:
				point = 1500;
				break;
		}
		
		if (npcId == 244769) {
			doors.get(183).setOpen(true);
		}

		if (point > 0) {
			if (instanceReward.getInstanceScoreType().isStartProgress()) {
				instanceReward.addPoints(point);
				if (npcId == 244777)
					stopInstanceTask();
				sendPacket(0, point);
			}
		}
	}
	
	@Override
	public void onCustomEventHandler(int eventId, Object... objects) {
		switch(eventId) {
			case 245506:
				deleteNpc(245957);
				deleteNpc(245961);
				spawn(244741, 749.7867f, 511.5630f, 339.729f, (byte)0); 
				spawn(244741, 751.8333f, 514.211f, 339.731f, (byte) 0); 
				spawn(244741, 749.8444f, 516.9772f, 339.7291f, (byte)0); 
				spawn(244741, 747.7722f, 514.3292f, 339.7365f, (byte) 0);
				break;
			case 245206:
				spawn(245814, 725.2301f, 515.5295f, 338.2485f, (byte)0);
				spawn(245814, 696.6752f, 504.3491f, 338.2485f, (byte)0);
				spawn(245814, 667.1929f, 510.5405f, 338.2485f, (byte)0);
				spawn(245814, 672.6748f, 523.3071f, 338.2484f, (byte)0);
				spawn(245814, 669.0969f, 520.3942f, 338.2484f, (byte)0);
				spawn(245672, 722.1654f, 513.4739f, 338.2485f, (byte)0);
				spawn(245672, 665.1359f, 521.1479f, 338.2484f, (byte)0);
				spawn(245668, 725.3655f, 502.6512f, 338.2485f, (byte)0);
				spawn(245668, 671.1499f, 512.3204f, 338.2485f, (byte)0);
				spawn(245812, 722.3144f, 503.7443f, 338.2485f, (byte)0);
				spawn(245664, 703.2942f, 514.3400f, 338.2485f, (byte)0);
				spawn(245664, 699.8584f, 506.5582f, 338.2485f, (byte)0);
				spawn(245664, 674.5864f, 510.4045f, 338.2485f, (byte)0);
				spawn(245813, 700.3963f, 517.0946f, 338.2485f, (byte)0);
				spawn(245813, 697.1297f, 515.6347f, 338.2485f, (byte)0);
				spawn(245813, 703.6778f, 503.8353f, 338.2484f, (byte)0);
				break;
			case 245212:
				spawn(245097, 629.9971f, 549.6639f, 343.8549f, (byte)100);
				spawn(245105, 628.1732f, 546.0257f, 343.8472f, (byte)100);
				spawn(245105, 626.1936f, 550.7659f, 345.0427f, (byte)100);
				spawn(245105, 627.9334f, 554.4822f, 344.6458f, (byte)100);
				spawn(245101, 623.6221f, 546.8151f, 345.0209f, (byte)100);
				break;
			case 245508:
				deleteNpc(245960);
				deleteNpc(245964);
				spawn(244744, 613.7373f, 609.2463f, 354.6971f, (byte)90);
				spawn(244744, 613.8405f, 613.4744f, 354.5460f, (byte)90);
				spawn(244744, 610.1555f, 612.7060f, 354.5460f, (byte)90);
				spawn(244744, 606.9803f, 613.4744f, 354.5460f, (byte)90);
				spawn(244744, 606.6581f, 609.2098f, 354.6971f, (byte)90);
				break;
			case 245222:
				spawn(244769, 510.8257f, 459.1535f, 322.0f, (byte)30);
				break;
			case 245513:
				deleteNpc(245954);
				deleteNpc(245958);
				spawn(244742, 384.5788f, 504.3145f, 350.3734f, (byte)30);
				spawn(244742, 377.0670f, 508.0422f, 350.3734f, (byte)15);
				spawn(244742, 384.4727f, 522.7825f, 350.3734f, (byte)90);
				spawn(244742, 377.4421f, 519.7426f, 350.3734f, (byte)105);
				spawn(244742, 392.5233f, 519.2856f, 350.3734f, (byte)75);
				spawn(244742, 392.4866f, 508.4113f, 350.3734f, (byte)45);
				break;
		}
	}

	private void deleteNpc(int npcId) {
		List<Npc> npcs = instance.getNpcs(npcId);
		for (Npc npc : npcs) {
			if (npc != null)
				npc.getController().delete();
		}
	}

	@Override
	public void onOpenDoor(int doorId) {
		StaticDoor door = doors.get(doorId);
		if (door != null)
			door.setOpen(true);
		if (door.isInstanceStartDoor() && !instanceReward.isStartProgress()) {
			if (instanceTimer != null)
				instanceTimer.cancel(true);
			StartInstanceTask();
		}
	}

	private void checkRank(int totalPoints) {
		int timeRemain = getTime();
		int rank = 0;
		if (timeRemain > 1200000 && totalPoints >= 23550) {
			rank = 1;
		}
		else if (timeRemain > 1080000 && totalPoints >= 21200) {
			rank = 2;
		}
		else if (timeRemain > 960000 && totalPoints >= 17700) {
			rank = 3;
		}
		else if (timeRemain > 600000 && totalPoints >= 14100) {
			rank = 4;
		}
		else if (timeRemain > 60000 && totalPoints >= 9400) {
			rank = 5;
		}
		else {
			rank = 8;
		}
		instanceReward.setRank(rank);
	}

	private int getTime() {
		long result = System.currentTimeMillis() - startTime;
		if (result < 180000 && !instanceReward.isStartProgress()) {
			return (int) (180000 - result);
		}
		else if (result < 1800000) {
			return (int) (1800000 - result);
		}
		return 0;
	}

	private void stopInstanceTask() {
		if (instanceTimer != null)
			instanceTimer.cancel(true);
		checkRank(instanceReward.getPoints());
		instanceReward.setInstanceScoreType(InstanceScoreType.END_PROGRESS);
	}

	private void sendPacket(final int nameId, final int point) {
		instance.doOnAllPlayers(new Visitor<Player>() {

			@Override
			public void visit(Player player) {
				PacketSendUtility.sendPacket(player, new SM_INSTANCE_SCORE(getTime(), instanceReward, null));
			}
		});
	}

	private void StartInstanceTask() {
		if (!instanceReward.isStartProgress()) {
			startTime = System.currentTimeMillis();
			instanceReward.setInstanceScoreType(InstanceScoreType.START_PROGRESS);
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

				@Override
				public void run() {
					stopInstanceTask();
					sendPacket(0, 0);
				}
			}, 1800000);
			sendPacket(0, 0);
		}
	}

	@Override
	public void onEnterInstance(final Player player) {
		if (instanceTimer == null) {
			startTime = System.currentTimeMillis();
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

				@Override
				public void run() {
					onOpenDoor(34);
				}
			}, 180000);
		}
		sendPacket(0, 0);
		//SkillEngine.getInstance().applyEffectDirectly(4829, player, player, 0);
	}
	
	@Override
	public void onPlayerLogOut(Player player) {
		//player.getEffectController().removeAllEffects();
		//player.getEffectController().removeEffect(4808);
		//player.getEffectController().removeEffect(4813);
		//player.getEffectController().removeEffect(4818);
		//player.getEffectController().removeEffect(4824);
	}

	@Override
	public void onLeaveInstance(Player player) {
		//player.getEffectController().removeAllEffects();
		//player.getEffectController().removeEffect(4808);
		//player.getEffectController().removeEffect(4813);
		//player.getEffectController().removeEffect(4818);
		//player.getEffectController().removeEffect(4824);
		//player.getEffectController().removeEffect(4829);
	}
	
	@Override
	public void onExitInstance(Player player) {
		InstanceService.destroyInstance(player.getPosition().getWorldMapInstance());
	}
	
	@Override
	public void onInstanceDestroy() {
		instanceTimer.cancel(true);
	}

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		instanceReward = new LunaInstanceReward(mapId, instanceId);
		doors = instance.getDoors();
		instanceReward.setInstanceScoreType(InstanceScoreType.PREPARING);
	}
}
