/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance;

import com.aionemu.gameserver.ai2.event.AIEventType;
import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;

/**
 * @author zxl001
 */
@InstanceID(MapID = 300800000, InstanceMaskID = 324)
public class KatalamadgeInstance extends GeneralInstanceHandler {

	private int ShieldGenerator = 0;
	private int Protectors = 0;

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
	}

	@Override
	public void onDie(Npc npc) {
		Npc shield = instance.getNpc(730741);
		final int npcId = npc.getNpcId();
		switch (npcId) {
			case 231074:
			case 231078:
			case 231082:
			case 231086:
				ShieldGenerator++;
				if (ShieldGenerator >= 4) {
					final Npc giperion = getNpc(231073);
					ShieldGenerator = 0;
					despawnNpc(shield);
					if (giperion != null && !giperion.getLifeStats().isAlreadyDead()) {
						ThreadPoolManager.getInstance().schedule(new Runnable() {
							@Override
							public void run() {
								giperion.getAi2().onCreatureEvent(AIEventType.CREATURE_AGGRO, instance.getPlayersInside().get(0));
							}
						}, 1000);
					}
				}
				break;
			case 231092:
			case 231093:
			case 231094:
			case 231095:
				Protectors++;
				if (Protectors == 4) {
					Protectors = 0;
					Npc giperion = getNpc(231073);
					if (giperion.getEffectController().hasAbnormalEffect(21371))
						giperion.getEffectController().removeEffect(21371);
					if (giperion.getEffectController().hasAbnormalEffect(21258))
						giperion.getEffectController().removeEffect(21258);
				}
				break;
			case 231073:
				spawn(730842, 124.66985f, 137.84067f, 112.17429f, (byte)0);
				break;
		}
	}

	private void despawnNpc(Npc npc) {
		if (npc != null) {
			npc.getController().onDelete();
		}
	}

	@Override
	public void onInstanceDestroy() {
		ShieldGenerator = 0;
		Protectors = 0;
	}
}
