/*
Aion-Finish <Ver:4.0>
 *
 *  Aion-Finish is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Aion-Finish is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Aion-Finish.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance;

import java.util.Map;
import java.util.Set;

import com.aionemu.commons.network.util.ThreadPoolManager;
import com.aionemu.commons.utils.Rnd;
import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.drop.DropItem;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.network.aion.serverpackets.SM_QUEST_ACTION;
import com.aionemu.gameserver.services.drop.DropRegistrationService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.world.WorldMapInstance;
import com.aionemu.gameserver.world.knownlist.Visitor;

@InstanceID(MapID = 301130000, InstanceMaskID = 317)
public class Sauro_Supply_Base extends GeneralInstanceHandler {

	Npc bossHistorianUterunerk = null;
	Npc bossBrigadeGeneralSheba = null;
	Npc bossGuardCaptainAhuradim = null;
	Npc bossMedicalOfficerSurkihan = null;
	Npc bossInterrogatingOfficerJadaraka = null;

	private boolean isInstanceDestroyed;
	private Map<Integer, StaticDoor> doors;
	
	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		doors = instance.getDoors();
		int rnd = Rnd.get(1, 5);
		switch (rnd) {
			case 1:
				spawn(230846, 464.07788f, 401.3575f, 182.15321f, (byte) 10);
				break;
			case 2:
				spawn(230846, 496.30792f, 412.814f, 182.13792f, (byte) 73);
				break;
			case 3:
				spawn(230846, 497.15717f, 392.34656f, 182.14955f, (byte) 75);
				break;
			case 4:
				spawn(230846, 496.2902f, 358.0765f, 182.14955f, (byte) 48);
				break;
			case 5:
				spawn(230846, 464.15985f, 389.7157f, 182.15321f, (byte) 109);
				break;
		}
		
		switch (Rnd.get(1, 7)) {
			case 1:
				spawn(230847, 263.3429f, 463.5408f, 156.70581f, (byte) 90);
				break;
			case 2:
				spawn(230847, 653.2666f, 372.9493f, 204.14606f, (byte) 72);
				break;
			case 3:
				spawn(230847, 498.09406f, 436.55927f, 182.11913f, (byte) 42);
				break;
			case 4:
				spawn(230847, 257.0982f, 364.2677f, 159.13574f, (byte) 119);
				break;
			case 5:
				spawn(230847, 322.7196f, 363.9511f, 159.13863f, (byte) 59);
				break;
			case 6:
				spawn(230847, 322.1051f, 388.41913f, 159.1054f, (byte) 60);
				break;
			case 7:
				spawn(230847, 262.72226f, 396.23676f, 156.83209f, (byte) 30);
				break;
		}
	}

	@Override
	public void onDropRegistered(Npc npc) {
		Set<DropItem> dropItems = DropRegistrationService.getInstance().geCurrentDropMap().get(npc.getObjectId());
		int npcId = npc.getNpcId();
		switch (npcId) {
			case 230847:
				dropItems.add(DropRegistrationService.getInstance().regDropItem(1, 0, npcId, 185000179, 1));
				break;
		}
	}

	@Override
	public void onDie(Npc npc) {
		Player player = npc.getAggroList().getMostPlayerDamage();
		switch (npc.getObjectTemplate().getTemplateId()) {
		/**
		 * Area 1: Guardroom And Rune Hall.
		 */
			case 230849: // Guard Captain Rohuka.
				sendMsg(1401914);
				doors.get(383).setOpen(true);
				break;
			case 230851:
				spawn(230797, 611.1872f, 452.91882f, 191.2776f, (byte) 39);
				spawn(230797, 610.7328f, 518.80884f, 191.2776f, (byte) 75);
				break;
			case 230797:
				sendMsg(1401915);
				doors.get(59).setOpen(true);
				break;

			/**
			 * Area 2: Rune Cloister And Logistic Base.
			 */
			case 230818: // Sheban Legion Elite Gunner.
				sendMsg(1401916);
				doors.get(372).setOpen(true);
				break;
			case 230850: // Research Teselik.
				sendMsg(1401917);
				doors.get(375).setOpen(true);
				break;

			/**
			 * Area 3: Rune Bridge And Logistic Base Arsenal.
			 */
			case 233255:
				sendMsg(1401918);
				doors.get(378).setOpen(true);
				break;
			case 230852:
				sendMsg(1401919);
				doors.get(388).setOpen(true);
				break;
			/**
			 * Area 4: Chiefs Chamber.
			 */
			case 230791:
				sendMsg(1401920);
				doors.get(376).setOpen(true);
				break;
			case 230853:
				sendMsg(1401921);
				spawn(730872, 131.85886f, 432.22598f, 151.66972f, (byte) 57, 3);
				break;
			case 230857:
			case 230858: // Brigade General Sheba's.
				PacketSendUtility.sendPacket(player, new SM_QUEST_ACTION(0, 120));
				ThreadPoolManager.getInstance().schedule(new Runnable() {

					@Override
					public void run() {
						instance.doOnAllPlayers(new Visitor<Player>() {

							@Override
							public void visit(Player player) {
								onExitInstance(player);
							}
						});
						onInstanceDestroy();
					}
				}, 120000);
				break;
		}
	}

	@Override
	public void onExitInstance(Player player) {
		TeleportService2.moveToInstanceExit(player, mapId, player.getRace());
	}

	@Override
	public void onInstanceDestroy() {
		doors.clear();
		isInstanceDestroyed = true;
	}
}
