/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.danuarmisticarium;

import java.util.List;
import java.util.Map;
import java.util.concurrent.Future;

import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.DescriptionId;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.instance.InstanceScoreType;
import com.aionemu.gameserver.model.instance.instancereward.DanuarMysticariumReward;
import com.aionemu.gameserver.model.items.storage.Storage;
import com.aionemu.gameserver.network.aion.serverpackets.SM_INSTANCE_SCORE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.services.abyss.AbyssPointsService;
import com.aionemu.gameserver.services.item.ItemService;
import com.aionemu.gameserver.services.player.PlayerReviveService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;
import com.aionemu.gameserver.world.knownlist.Visitor;

/**
 * @author Ranastic
 */
@InstanceID(MapID = 300480000, InstanceMaskID = 0)
public class Danuar_Mysticarium_Solo extends GeneralInstanceHandler {

	private long startTime;
	private Future<?> instanceTimer;
	@SuppressWarnings("unused")
	private boolean isInstanceDestroyed;
	private Map<Integer, StaticDoor> doors;
	private DanuarMysticariumReward instanceReward;

	@Override
	public void onDie(Npc npc) {
		int points = 0;
		int npcId = npc.getNpcId();
		Player player = npc.getAggroList().getMostPlayerDamage();
		switch (npc.getObjectTemplate().getTemplateId()) {
			case 230062:
			case 230063:
			case 230064:
				points = 150;
				break;
			case 230066:
			case 230067:
			case 230078:
			case 230079:
				points = 285;
				break;
			case 230074:
				points = 1125;
				break;
			case 230051:
			case 230052:
			case 230053:
			case 230054:
			case 230055:
			case 230056:
			case 230057:
			case 230058:
				points = 2010;
				break;
			case 230081: // Sheban Intelligence Captain.
				points = 3051;
				break;
			case 272762:
				despawnNpc(npc);
				break;
		}
		if (instanceReward.getInstanceScoreType().isStartProgress()) {
			instanceReward.addPoints(points);
			sendPacket(npc.getObjectTemplate().getNameId(), points);
		}
		switch (npcId) {
			case 230081: // Sheban Intelligence Captain.
				stopInstance(player);
				break;
			case 233253:
				spawn(701572, 556.5924f, 416.37885f, 96.81002f, (byte) 43); // Danuar Mysticarium Exit.
				break;
			case 233254:// Frenzied Chairman Nautius.
				spawn(701572, 556.5924f, 416.37885f, 96.81002f, (byte) 43); // Danuar Mysticarium Exit.
				break;
		}
	}

	public void removeItems(Player player) {
		Storage storage = player.getInventory();
		storage.decreaseByItemId(185000127, storage.getItemCountByItemId(185000127)); // Idgel Storage Key.
		storage.decreaseByItemId(185000165, storage.getItemCountByItemId(185000165)); // Idgel Storage Key.
	}

	@Override
	public void handleUseItemFinish(Player player, Npc npc) {
		if (!instanceReward.isStartProgress())
			return;
		int points = instanceReward.getNpcBonus(npc.getNpcId());
		instanceReward.addPoints(points);
		sendPacket(npc.getObjectTemplate().getNameId(), points);
	}

	private int getTime() {
		long result = System.currentTimeMillis() - startTime;
		if (result < 60000 && !instanceReward.isStartProgress())
			return (int) (60000 - result);
		else if (result < 1800000 && instanceReward.isStartProgress())
			return (int) (1800000 - result);
		return 0;
	}

	private void sendPacket(final int nameId, final int point) {
		final List<Player> players = instance.getPlayersInside();
		instance.doOnAllPlayers(new Visitor<Player>() {

			@Override
			public void visit(Player player) {
				if (nameId != 0 && point != 0)
					PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1400237, new DescriptionId(nameId * 2 + 1), point));
				PacketSendUtility.sendPacket(player, new SM_INSTANCE_SCORE(getTime(), instanceReward, players));
			}
		});
	}

	private int checkRank(int totalPoints) {
		int rank = 7;
		long Remainingtime = System.currentTimeMillis() - startTime;
		if (totalPoints > 30481 && Remainingtime <= 720000) // Rank S.
			rank = 1;
		else if (totalPoints > 22252 && Remainingtime <= 840000) // Rank A.
			rank = 2;
		else if (totalPoints > 15394 && Remainingtime <= 1080000) // Rank B.
			rank = 3;
		else if (totalPoints > 9908 && Remainingtime <= 1440000) // Rank C.
			rank = 4;
		else if (totalPoints > 7165 && Remainingtime <= 1680000) // Rank D.
			rank = 5;
		else
			rank = 8;
		return rank;
	}

	@Override
	public void onEnterInstance(final Player player) {
		if (instanceTimer == null) {
			startTime = System.currentTimeMillis();
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

				@Override
				public void run() {
					onOpenDoor(3);
				}
			}, 60000);
		}
		sendPacket(0, 0);
	}

	private void StartInstanceTask() {

		if (!instanceReward.isStartProgress()) {
			startTime = System.currentTimeMillis();
			instanceReward.setInstanceScoreType(InstanceScoreType.START_PROGRESS);
			instanceReward.getInstanceScoreType().isStartProgress();
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

				@Override
				public void run() {
					instance.doOnAllPlayers(new Visitor<Player>() {

						@Override
						public void visit(Player player) {
							stopInstance(player);
						}
					});
				}
			}, 1800000);
			sendPacket(0, 0);
		}
	}

	protected void stopInstance(Player player) {
		stopInstanceTask();
		instanceReward.setRank(checkRank(instanceReward.getPoints()));
		instanceReward.setInstanceScoreType(InstanceScoreType.END_PROGRESS);
		doReward(player);
		sendPacket(0, 0);
	}

	private void stopInstanceTask() {
		if (instanceTimer != null)
			instanceTimer.cancel(true);
	}

	@Override
	public void doReward(Player player) {
		int rank = checkRank(instanceReward.getPoints());
		if (!instanceReward.isRewarded()) {
			instanceReward.setRewarded();
			if (rank <= 5) {
				float rewardSillus = (instanceReward.getPoints() >> 8) / (rank + 7);
				float rewardAp = (instanceReward.getPoints() * 0.06f) - rank * 200;
				instanceReward.setScoreAP((int) rewardAp);
				AbyssPointsService.addAGp(player, (int) rewardAp, 0); // 欧比斯
				instanceReward.setSillus((int) rewardSillus);
				ItemService.addItem(player, 186000239, (int) rewardSillus); // 要塞纹章
				if (rank == 1) {
					instanceReward.setCeramium(1);
					ItemService.addItem(player, 186000242, 1); // 黑金铸币.
					ItemService.addItem(player, 188052543, 1); // 荣誉奖励品
				}
				else if (rank == 2) {
					instanceReward.setFavorable(3);
					ItemService.addItem(player, 186000243, 3); // 破碎的黑金
					ItemService.addItem(player, 188052547, 1); // 勇敢奖励品
				}
				else if (rank == 3) {
					instanceReward.setFavorable(1);
					ItemService.addItem(player, 186000243, 1); // 破碎的黑金
				}
			}
		}
	}

	@Override
	public void onLeaveInstance(Player player) {
		removeItems(player);
	}

	@Override
	public void onInstanceDestroy() {
		if (instanceTimer != null)
			instanceTimer.cancel(false);
		isInstanceDestroyed = true;
		doors.clear();
	}

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		instanceReward = new DanuarMysticariumReward(mapId, instanceId);
		instanceReward.setInstanceScoreType(InstanceScoreType.PREPARING);
		doors = instance.getDoors();
	}

	private void despawnNpc(Npc npc) {
		if (npc != null)
			npc.getController().onDelete();
	}

	@Override
	public void onOpenDoor(int doorId) {
		StaticDoor door = doors.get(doorId);
		if (door != null)
			door.setOpen(true);
		if (door.isInstanceStartDoor() && !instanceReward.isStartProgress()) {
			if (instanceTimer != null)
				instanceTimer.cancel(true);
			StartInstanceTask();
		}
	}

	@Override
	public void onStopTraining(Player player) {
		onExitInstance(player);
	}

	@Override
	public void onExitInstance(Player player) {
		TeleportService2.moveToInstanceExit(player, mapId, player.getRace());
	}

	@Override
	public boolean onReviveEvent(Player player) {
		PlayerReviveService.revive(player, 100, 100, false, 0);
		player.getGameStats().updateStatsAndSpeedVisually();
		PacketSendUtility.sendPacket(player, SM_SYSTEM_MESSAGE.STR_REBIRTH_MASSAGE_ME);
		TeleportService2.teleportTo(player, mapId, instanceId, 184.35031f, 121.30565f, 231.287f, (byte) 60);
		return true;
	}
}
