/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.idgelresearchcenter;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Future;

import com.aionemu.commons.utils.Rnd;
import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.DescriptionId;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.instance.InstanceScoreType;
import com.aionemu.gameserver.model.instance.instancereward.IdgelResearchCenterReward;
import com.aionemu.gameserver.model.templates.spawns.SpawnSpotTemplate;
import com.aionemu.gameserver.network.aion.serverpackets.SM_INSTANCE_SCORE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_SYSTEM_MESSAGE;
import com.aionemu.gameserver.services.abyss.AbyssPointsService;
import com.aionemu.gameserver.services.item.ItemService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.skillengine.SkillEngine;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;
import com.aionemu.gameserver.world.knownlist.Visitor;

/**
 * @author zxl001
 */
@InstanceID(MapID = 300530000, InstanceMaskID = 0)
public class Idgel_Research_Center_Solo extends GeneralInstanceHandler {

	private long startTime;
	private Future<?> instanceTimer;
	private boolean isInstanceDestroyed;
	private Map<Integer, StaticDoor> doors;
	private IdgelResearchCenterReward instanceReward;

	@Override
	public void onDie(Npc npc) {
		int points = 0;
		int npcId = npc.getNpcId();
		switch (npcId) {
			case 230119: // Reian Victim.
				points = 20;
				sendMsg(1401924); // Reian Victim Die.
				despawnNpc(npc);
				if (getNpcs(230119).isEmpty()) { // Reian Victim.
					sendMsg(1401925); // All Reian Victim Die.
				}
				break;
			case 230117: // Encrusted Sparkle.
				points = 100;
				break;
			case 230110: // Unmaker.
			case 230120: // Sheban Drakan Bladesman.
				points = 200;
				break;
			case 230112: // Purifying Sweetsteppe.
				points = 350;
				break;
			case 230106: // Flame Beast.
			case 230107: // Marabata The Furious.
			case 230113: // Weaponized Ragnarok.
			case 230114: // Reforged RA-45C.
			case 230115: // Evolved Scar.
			case 230116: // Chieftain Sukka.
				points = 400;
				break;
			case 230108: // Lighning Engine.
			case 230111: // Darkcaller Macunbello.
				points = 500;
				break;
			case 230121: // Retributive Effigy.
				points = 600;
				break;
			case 233266: // Sheban Research Supervisor.
				points = 1000;
				break;
		}
		if (instanceReward.getInstanceScoreType().isStartProgress()) {
			instanceReward.addPoints(points);
			sendPacket(npc.getObjectTemplate().getNameId(), points);
			if (instanceReward.getPoints() >= 5000)
				stopInstance();
		}
	}

	private int getTime() {
		long result = System.currentTimeMillis() - startTime;
		if (result < 60000 && !instanceReward.isStartProgress()) {
			return (int) (60000 - result);
		}
		else if (result < 600000 && instanceReward.isStartProgress()) {
			return (int) (600000 - result);
		}
		return 0;
	}

	private void sendPacket(final int nameId, final int point) {
		final List<Player> players = instance.getPlayersInside();
		instance.doOnAllPlayers(new Visitor<Player>() {

			@Override
			public void visit(Player player) {
				if (nameId != 0) {
					PacketSendUtility.sendPacket(player, new SM_SYSTEM_MESSAGE(1400237, new DescriptionId(nameId * 2 + 1), point));
				}
				PacketSendUtility.sendPacket(player, new SM_INSTANCE_SCORE(getTime(), instanceReward, players));
			}
		});
	}

	private int checkRank(int totalPoints) {
		int rank = 0;
		if (totalPoints >= 5000) { // Rank S.
			rank = 1;
		}
		else if (totalPoints > 3500) { // Rank A.
			rank = 2;
		}
		else if (totalPoints > 2700) { // Rank B.
			rank = 3;
		}
		else if (totalPoints > 2200) { // Rank C.
			rank = 4;
		}
		else if (totalPoints > 1600) { // Rank D.
			rank = 5;
		}
		else if (totalPoints > 500) { // Rank F.
			rank = 6;
		}
		else {
			rank = 8;
		}
		return rank;
	}

	@Override
	public void onEnterInstance(final Player player) {
		if (instanceTimer == null) {
			startTime = System.currentTimeMillis();
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

				@Override
				public void run() {
					onOpenDoor(32);
				}
			}, 60000);
		}
		sendPacket(0, 0);
	}

	protected void stopInstance() {
		stopInstanceTask();
		int rank = checkRank(instanceReward.getPoints());
		if (rank <= 5)
			spawn(730730, 571.1385f, 444.94006f, 102.65536f, (byte) 30);
		instanceReward.setRank(rank);
		instanceReward.setInstanceScoreType(InstanceScoreType.END_PROGRESS);
		if (!instanceReward.isRewarded())
			instanceReward.setRewarded();
		instance.doOnAllPlayers(new Visitor<Player>() {

			@Override
			public void visit(Player object) {
				doReward(object);
			}
		});
		sendPacket(0, 0);
	}

	private void stopInstanceTask() {
		if (instanceTimer != null)
			instanceTimer.cancel(true);
	}

	@Override
	public void doReward(Player player) {
		int rank = checkRank(instanceReward.getPoints());
		if (rank <= 5) {
			float rewardSillus = (instanceReward.getPoints() >> 8) / (rank + 7);
			float rewardAp = (instanceReward.getPoints() * 0.06f) - rank * 200;
			instanceReward.setScoreAP((int) rewardAp);
			AbyssPointsService.addAGp(player, (int) rewardAp, 0); // 欧比斯
			if (rewardSillus > 1) {
				instanceReward.setSillus((int) rewardSillus);
				ItemService.addItem(player, 186000241, (int) rewardSillus); // 要塞纹章
			}
			if (rank == 1) {
				instanceReward.setCeramium(1);
				ItemService.addItem(player, 186000242, 1); // 黑金铸币.
				ItemService.addItem(player, 188052543, 1); // 荣誉奖励品
			}
			else if (rank == 2) {
				instanceReward.setFavorable(3);
				ItemService.addItem(player, 186000243, 3); // 破碎的黑金
				ItemService.addItem(player, 188052547, 1); // 勇敢奖励品
			}
			else if (rank == 3) {
				instanceReward.setFavorable(1);
				ItemService.addItem(player, 186000243, 1); // 破碎的黑金
			}
		}
	}

	@Override
	public void handleUseItemFinish(Player player, Npc npc) {
		switch (npc.getNpcId()) {
			case 230124:
				Npc boss = instance.getNpc(230121);
				if (boss != null) {
					boss.getEffectController().removeEffect(19406);
				}
				break;
		}
	}

	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		instanceReward = new IdgelResearchCenterReward(mapId, instanceId);
		instanceReward.setInstanceScoreType(InstanceScoreType.PREPARING);
		doors = instance.getDoors();
		bossspawn();
		chestspawn();
		Npc npc = instance.getNpc(230121);
		if (npc != null) {
			SkillEngine.getInstance().getSkill(npc, 19406, 1, npc).useNoAnimationSkill();
		}
	}

	protected List<Npc> getNpcs(int npcId) {
		if (!isInstanceDestroyed) {
			return instance.getNpcs(npcId);
		}
		return null;
	}

	private void despawnNpc(Npc npc) {
		if (npc != null) {
			npc.getController().onDelete();
		}
	}

	@Override
	public void onInstanceDestroy() {
		if (instanceTimer != null)
			instanceTimer.cancel(false);
		isInstanceDestroyed = true;
		instanceReward.clear();
		doors.clear();
	}

	@Override
	public void onOpenDoor(int doorId) {
		StaticDoor door = doors.get(doorId);
		if (door != null) {
			door.setOpen(true);
		}
		if (door.isInstanceStartDoor() && !instanceReward.isStartProgress()) {
			if (instanceTimer != null)
				instanceTimer.cancel(true);
			StartInstanceTask();
		}
	}

	private void StartInstanceTask() {
		startTime = System.currentTimeMillis();
		instanceReward.setInstanceScoreType(InstanceScoreType.START_PROGRESS);
		instanceReward.getInstanceScoreType().isStartProgress();
		instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

			@Override
			public void run() {
				stopInstance();
			}
		}, 600000);
		sendPacket(0, 0);
	}
	
	private void bossspawn() {
		int[] bossIds = new int[] { 230108, 230110, 230111, 230112, 230113, 230115, 230116 };
		List<SpawnSpotTemplate> spots = new ArrayList<SpawnSpotTemplate>();
		spots.add(new SpawnSpotTemplate(662.91956f, 467.39224f, 102.64f, (byte) 60, 0, "", null));
		spots.add(new SpawnSpotTemplate(590.21265f, 501.8281f, 102.68871f, (byte) 90, 0, "", null));
		spots.add(new SpawnSpotTemplate(478.8857f, 468.1526f, 102.6373f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(482.32465f, 429.7620f, 102.64238f, (byte) 15, 0, "", null));
		spots.add(new SpawnSpotTemplate(494.82263f, 513.02167f, 109.68598f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(613.3185f, 504.96155f, 102.6887f, (byte) 66, 0, "", null));
		spots.add(new SpawnSpotTemplate(501.5816f, 433.84262f, 102.64236f, (byte) 30, 0, "", null));
		for(int i =0; i < bossIds.length; i++) {
			int index = Rnd.get(0, spots.size() - 1);
			spawn(bossIds[i], spots.get(index));
			spots.remove(index);
		}
	}
	
	private void chestspawn() {
		List<SpawnSpotTemplate> spots = new ArrayList<SpawnSpotTemplate>();
		spots.add(new SpawnSpotTemplate(575.02686f, 466.26486f, 102.65535f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(497.36856f, 473.52557f, 102.69315f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(591.8686f, 481.77136f, 102.79826f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(643.3046f, 482.29f, 102.64990f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(512.2397f, 513.48145f, 109.71619f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(625.60956f, 455.2664f, 102.44161f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(516.42127f, 482.2241f, 102.63606f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(550.18964f, 491.09506f, 102.65827f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(527.52875f, 527.0185f, 109.71619f, (byte) 0, 0, "", null));
		spots.add(new SpawnSpotTemplate(610.2532f, 423.13248f, 97.22831f, (byte) 0, 0, "", null));
		for(int i = 0; i < 10; i++) {
			int chentid = i < 5 ? 230105 : 701570;
			int index = Rnd.get(0, spots.size() - 1);
			spawn(chentid, spots.get(index));
			spots.remove(index);
		}
	}

	@Override
	public void onStopTraining(Player player) {
		onExitInstance(player);
	}

	@Override
	public void onExitInstance(Player player) {
		TeleportService2.moveToInstanceExit(player, mapId, player.getRace());
	}
}
