/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.luna;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Future;

import com.aionemu.gameserver.ai2.NpcAI2;
import com.aionemu.gameserver.ai2.manager.WalkManager;
import com.aionemu.gameserver.instance.handlers.GeneralInstanceHandler;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.EmotionType;
import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Creature;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.StaticDoor;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.model.instance.InstanceScoreType;
import com.aionemu.gameserver.model.instance.instancereward.LunaInstanceReward;
import com.aionemu.gameserver.network.aion.serverpackets.SM_DIE;
import com.aionemu.gameserver.network.aion.serverpackets.SM_EMOTION;
import com.aionemu.gameserver.network.aion.serverpackets.SM_INSTANCE_SCORE;
import com.aionemu.gameserver.services.item.ItemService;
import com.aionemu.gameserver.services.player.PlayerReviveService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.skillengine.SkillEngine;
import com.aionemu.gameserver.utils.PacketSendUtility;
import com.aionemu.gameserver.utils.ThreadPoolManager;
import com.aionemu.gameserver.world.WorldMapInstance;
import com.aionemu.gameserver.world.knownlist.Visitor;

/**
 * @author 81002
 */
@InstanceID(MapID = 301640000, InstanceMaskID = 0)
public class Luna301640000 extends GeneralInstanceHandler {
	
	private Future<?> instanceTimer;
	private long startTime;
	private LunaInstanceReward instanceReward;
	private Map<Integer, StaticDoor> doors;
	private Npc door1;
	
	@Override
	public void onDie(Npc npc) {
		Creature master = npc.getMaster();
		if (master instanceof Player)
			return;
		
		int npcId = npc.getNpcId();
		int point = 0;
		switch (npcId) {
			case 243663:
				spawn(244147, 149.5466f, 259.4240f, 191.8727f, (byte) 0);
				break;
			case 244147:
				int minPoint = (int)(getTime() / 1000 / 60) * 10000;
				point = 400000 + minPoint;
				deleteNpcs();
				break;
		}
		if (point > 0) {
			if (instanceReward.getInstanceScoreType().isStartProgress()) {
				instanceReward.addPoints(point);
				if (npcId == 244147)
					stopInstanceTask();
				sendPacket(0, point);
			}
		}
	}
	
	private void StartInstanceTask() {
		if (!instanceReward.isStartProgress()) {
			startTime = System.currentTimeMillis();
			instanceReward.setInstanceScoreType(InstanceScoreType.START_PROGRESS);
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {
				
				@Override
				public void run() {
					stopInstanceTask();
					sendPacket(0, 0);
				}
			}, 3600000);
			sendPacket(0, 0);
			door1.getController().die();
			spawnNpcs();
		}
	}
	
	private void spawnNpcs() {
		try {
			Npc npc = (Npc) spawn(833829, 382.4136f, 283.8347f, 198.5082f, (byte) 60);
			npc.getSpawn().setWalkerId("INSTANCE_WALKER_301640001");
			Thread.sleep(200);
			WalkManager.startWalking((NpcAI2) npc.getAi2());
			npc = (Npc) spawn(833827, 385.9122f, 282.7136f, 198.1743f, (byte) 60);
			npc.getSpawn().setWalkerId("INSTANCE_WALKER_301640001");
			Thread.sleep(200);
			WalkManager.startWalking((NpcAI2) npc.getAi2());
			npc = (Npc) spawn(833826, 385.2850f, 286.9142f, 198.5604f, (byte) 60);
			npc.getSpawn().setWalkerId("INSTANCE_WALKER_301640001");
			Thread.sleep(200);
			WalkManager.startWalking((NpcAI2) npc.getAi2());
			npc = (Npc) spawn(833897, 387.9199f, 281.4579f, 198.0898f, (byte) 60);
			npc.getSpawn().setWalkerId("INSTANCE_WALKER_301640001");
			Thread.sleep(200);
			WalkManager.startWalking((NpcAI2) npc.getAi2());
			npc = (Npc) spawn(833828, 387.5144f, 289.1547f, 198.4872f, (byte) 60);
			npc.getSpawn().setWalkerId("INSTANCE_WALKER_301640001");
			Thread.sleep(200);
			WalkManager.startWalking((NpcAI2) npc.getAi2());
		}
		catch (Exception e) {
		}
	}
	
	private void deleteNpcs() {
		List<Integer> npcs = Arrays.asList(833829, 833827, 833826, 833897, 833828);
		for(int id : npcs) {
			Npc npc = getNpc(id);
			if (npc != null) {
				npc.getController().delete();
			}
		}
	}
	
	@Override
	public void onOpenDoor(int doorId) {
		StaticDoor door = doors.get(doorId);
		if (door != null)
			door.setOpen(true);
		if (door.isInstanceStartDoor() && !instanceReward.isStartProgress()) {
			if (instanceTimer != null)
				instanceTimer.cancel(true);
			StartInstanceTask();
		}
	}
	
	private void stopInstanceTask() {
		if (instanceTimer != null)
			instanceTimer.cancel(true);
		checkRank(instanceReward.getPoints());
		instanceReward.setInstanceScoreType(InstanceScoreType.END_PROGRESS);
	}
	
	private void checkRank(int totalPoints) {
		int timeRemain = getTime();
		int rank = 0;
		if (timeRemain > 2880000 && totalPoints >= 878600) {
			rank = 1;
		}
		else if (timeRemain > 0 && totalPoints >= 0) {
			rank = 2;
		}
		instanceReward.setRank(rank);
	}
	
	@Override
	public void onInstanceCreate(WorldMapInstance instance) {
		super.onInstanceCreate(instance);
		doors = instance.getDoors();
		instanceReward = new LunaInstanceReward(mapId, instanceId);
		instanceReward.setInstanceScoreType(InstanceScoreType.PREPARING);
		door1 = getNpc(833868);
	}
	
	private int getTime() {
		long result = System.currentTimeMillis() - startTime;
		if (result < 120000 && !instanceReward.isStartProgress()) {
			return (int) (120000 - result);
		}
		else if (result < 3600000) {
			return (int) (3600000 - result);
		}
		return 0;
	}

	private void sendPacket(final int nameId, final int point) {
		instance.doOnAllPlayers(new Visitor<Player>() {

			@Override
			public void visit(Player player) {
				PacketSendUtility.sendPacket(player, new SM_INSTANCE_SCORE(getTime(), instanceReward, null));
			}
		});
	}
	
	@Override
	public void onEnterInstance(final Player player) {
		if (instanceTimer == null) {
			startTime = System.currentTimeMillis();
			instanceTimer = ThreadPoolManager.getInstance().schedule(new Runnable() {

				@Override
				public void run() {
					onOpenDoor(27);
				}
			}, 180000);
		}
		sendPacket(0, 0);
		SkillEngine.getInstance().applyEffectDirectly(21347, player, player, 0);
	}
	
	@Override
	public void doReward(Player player) {
		if (instanceReward.isRewarded()) {
			int itemId = instanceReward.getRank() == 1 ? 188055475 : 188055647;
			ItemService.addItem(player, itemId, 1);
		}
	}
	
	@Override
	public void onLeaveInstance(Player player) {
		player.getEffectController().removeEffect(21347);
		if (!instanceTimer.isDone())
			instanceTimer.cancel(true);
	}

  @Override
  public boolean onDie(final Player player, Creature lastAttacker) {
      PacketSendUtility.broadcastPacket(player, new SM_EMOTION(player, EmotionType.DIE, 0, player.equals(lastAttacker) ? 0 : lastAttacker.getObjectId()), true);
      PacketSendUtility.sendPacket(player, new SM_DIE(player.haveSelfRezEffect(), player.haveSelfRezItem(), 0, 8));
      return true;
  }
  
  @Override
	public boolean onReviveEvent(Player player) {
  	PlayerReviveService.revive(player, 100, 100, false, 0);
		player.getGameStats().updateStatsAndSpeedVisually();
  	TeleportService2.teleportTo(player, player.getWorldId(), player.getInstanceId(), 400.3279F, 290.5061F, 198.6402F, (byte) 60);
  	return true;
  }
  
	@Override
	public void onExitInstance(Player player) {
		TeleportService2.teleportTo(player, player.getEnterWorldId(), player.getEnterX(), player.getEnterY(), player.getEnterZ(), player.getHeading(), TeleportAnimation.BEAM_ANIMATION);
	}
}
