/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package instance.ophidanbridgewar;

import com.aionemu.commons.utils.Rnd;
import com.aionemu.gameserver.controllers.effect.PlayerEffectController;
import com.aionemu.gameserver.instance.handlers.InstanceID;
import com.aionemu.gameserver.model.Race;
import com.aionemu.gameserver.model.actions.NpcActions;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.skillengine.SkillEngine;

/**
 * @author Ranastic
 */
@InstanceID(MapID = 301210000, InstanceMaskID = 108)
public class Ophidan_Bridge_War extends Ophidan_Bridge_War_Controller
{
    @Override
	public void onEnterInstance(Player player) {
		if (isInstanceStarted.compareAndSet(false, true)) {
			sp(216890, 499.52f, 598.67f, 390.49f, (byte) 59, 720000);
			int rnd = Rnd.get(1, 2);
			switch (rnd) {
				case 1:
				    spawn(215093, 485.41727f, 319.09863f, 403.26712f, (byte) 110);
				break;
				case 2:
				    sendMsgByRace(1400633, Race.PC_ALL, 0);
				    spawn(216941, 485.99f, 299.23f, 402.57f, (byte) 30);
				break;
			}
			int spawnTime = Rnd.get(10, 15) * 60 * 1000 + 120000;
			sendMsgByRace(1400632, Race.PC_ALL, spawnTime);
			sp(214823, 485.2116f, 807.46875f, 416.86816f, (byte) 117, spawnTime);
			startInstanceTask();
		}
		super.onEnterInstance(player);
	}
	
	@Override
	public void onDie(Npc npc) {
		Player mostPlayerDamage = npc.getAggroList().getMostPlayerDamage();
		if (mostPlayerDamage == null) {
			return;
		}
		Race race = mostPlayerDamage.getRace();
		switch (npc.getObjectTemplate().getTemplateId()) {
			case 000000:
				updateScore(mostPlayerDamage, npc, 200, false);
			return;
			case 000001:
				if (!ophidanBridgeWarReward.isRewarded()) {
					updateScore(mostPlayerDamage, npc, 30000, false);
					Race winningRace = ophidanBridgeWarReward.getWinningRaceByScore();
					stopInstance(winningRace);
				}
			return;
		}
		super.onDie(npc);
	}
	
	@Override
	public void handleUseItemFinish(Player player, Npc npc) {
		switch (npc.getNpcId()) {
			case 701898: //Ophidan Tank Elyos.
				SkillEngine.getInstance().getSkill(npc, 21403, 1, player).useNoAnimationSkill();
				NpcActions.scheduleRespawn(npc);
				despawnNpc(npc);
			break;
			case 701899: //Ophidan Tank Asmodians.
				SkillEngine.getInstance().getSkill(npc, 21404, 1, player).useNoAnimationSkill();
				NpcActions.scheduleRespawn(npc);
				despawnNpc(npc);
			break;
		}
	}
	
	private void removeEffects(Player player) {
		PlayerEffectController effectController = player.getEffectController();
		effectController.removeEffect(21403);
		effectController.removeEffect(21404);
	}
	
	@Override
	public void onLeaveInstance(Player player) {
		removeEffects(player);
	}
	
	@Override
	public void onPlayerLogOut(Player player) {
		removeEffects(player);
	}
	
	private void despawnNpc(Npc npc) {
		if (npc != null) {
			npc.getController().onDelete();
		}
	}
	
	@Override
	protected void openFirstDoors() {
		openDoor(4);
		openDoor(8);
	}
}