/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.LF6;

import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.HandlerResult;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;

/**
 * @author 81002
 */
public class _10504MattTheTreasure extends QuestHandler {

	private final static int questId = 10504;

	public _10504MattTheTreasure() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(804706).addOnTalkEvent(questId);
		qe.registerQuestNpc(702671).addOnTalkEvent(questId);
		qe.registerQuestNpc(236253).addOnKillEvent(questId);
		qe.registerQuestNpc(236254).addOnKillEvent(questId);
		qe.registerQuestNpc(236255).addOnKillEvent(questId);
		qe.registerQuestItem(182215606, questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		int var = qs.getQuestVarById(0);
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 804706:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 0)
								return sendQuestDialog(env, 1011);
							else if (var == 3)
								return sendQuestDialog(env, 2034);
						case STEP_TO_1:
							giveQuestItem(env, 182215606, 1);
							return defaultCloseDialog(env, 0, 1);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 3, 3, true, 10000, 10001);
					}
					break;
				case 702671:
					switch(env.getDialog()) {
						case USE_OBJECT:
							return useQuestObject(env, 3, 3, false, true);
					}
					break;
			}
		}
		else {
			if (targetId == 804706 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.USE_OBJECT) {
					return sendQuestDialog(env, 10002);
				}
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}

	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		int var = qs.getQuestVarById(0);
		int targetId = env.getTargetId();
		if (var == 1) {
			switch(targetId) {
				case 236253:
				case 236254:
					int var1 = qs.getQuestVarById(1);
					if (var1 + 1 == 5)
						qs.setQuestVar(2);
					return defaultOnKillEvent(env, targetId, 0, 5, 1);
			}
		}
		return false;
	}
	
	public HandlerResult onItemUseEvent(QuestEnv env, Item item) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return HandlerResult.UNKNOWN;
		int var = qs.getQuestVarById(0);
		if (var == 2 && item.getItemId() == 182215606) {
			int targetId = env.getTargetId();
			if (targetId == 236255) {
				if (HandlerResult.fromBoolean(useQuestItem(env, item, 2, 3, false)) == HandlerResult.SUCCESS) {
					removeQuestItem(env, 182215606, 1);
					return HandlerResult.SUCCESS;
				}
			}
		}
		return HandlerResult.UNKNOWN;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
