/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.LF6;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.QuestService;


/**
 * @author 81002
 *
 */
public class _10506EnterCorridor extends QuestHandler {

	private final static int questId = 10506;

	public _10506EnterCorridor() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(804709).addOnTalkEvent(questId);
		qe.registerQuestNpc(804710).addOnTalkEvent(questId);
		qe.registerQuestNpc(702666).addOnAtDistanceEvent(questId);
		qe.registerQuestNpc(236259).addOnKillEvent(questId);
		qe.registerQuestNpc(236263).addOnKillEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		int var = qs.getQuestVarById(0);
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 804709:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 804710:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 1)
								return sendQuestDialog(env, 1352);
							else if (var == 5)
								return sendQuestDialog(env, 2716);
							else if (var == 7)
								return sendQuestDialog(env, 3398);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
						case STEP_TO_6:
							QuestService.addNewSpawn(210070000, player.getInstanceId(), 216263, 2398f, 2294f, 322f, (byte)102);
							return defaultCloseDialog(env, 5, 6);
						case SET_REWARD:
							qs.setQuestVar(8);
							qs.setStatus(QuestStatus.REWARD);
							updateQuestStatus(env);
							return closeDialogWindow(env);
					}
			}
		}
		else {
			if (targetId == 804709 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		int var = qs.getQuestVarById(0);
		if (var == 3) {
			int var1 = qs.getQuestVarById(1);
			if (var1 + 1 == 2)
				qs.setQuestVar(5);
			return defaultOnKillEvent(env, 236259, 0, 2, 1);
		}
		else if (var == 3) {
			return defaultOnKillEvent(env, 216263, 6, false);
		}
		return false;
	}
	
	@Override
	public boolean onAtDistanceEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		int targetId = env.getTargetId();
		if (targetId == 702666) {
			return defaultFollowEndEvent(env, 2, 3, false);
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
