/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.LF6;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;


/**
 * @author 81002
 *
 */
public class _10507SupportTeam extends QuestHandler {

	private final static int questId = 10507;

	public _10507SupportTeam() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(804711).addOnTalkEvent(questId);
		qe.registerQuestNpc(804712).addOnTalkEvent(questId);
		qe.registerQuestNpc(804713).addOnTalkEvent(questId);
		qe.registerQuestNpc(804714).addOnTalkEvent(questId);
		qe.registerQuestNpc(804715).addOnTalkEvent(questId);
		qe.registerQuestNpc(236264).addOnKillEvent(questId);
		qe.registerQuestNpc(236265).addOnKillEvent(questId);
		qe.registerQuestNpc(702668).addOnKillEvent(questId);
		qe.registerQuestNpc(206366).addOnAtDistanceEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		int var = qs.getQuestVarById(0);
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 804711:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 0)
							  return sendQuestDialog(env, 1011);
							else if (var == 4)
								return sendQuestDialog(env, 2375);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
						case STEP_TO_5:
							return defaultCloseDialog(env, 4, 5);
					}
					break;
				case 804712:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
					}
					break;
				case 804713:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 804714:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2034);
						case STEP_TO_4:
							return defaultCloseDialog(env, 3, 4);
					}
					break;
				case 804715:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6);
					}
					break;
			}
		}
		else {
			if (targetId == 804711 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		int var = qs.getQuestVarById(0);
		int targetId = env.getTargetId();
		if (var == 6) {
			int var1 = qs.getQuestVarById(1);
			int var2 = qs.getQuestVarById(2);
			switch(targetId) {
				case 236264:
				case 236265:
					if (var2 == 3 && var1 + 1 == 5)
						qs.setQuestVar(7);
					return defaultOnKillEvent(env, targetId, 0, 5, 1);
				case 702668:
					if (var1 == 5 && var2 + 1 == 3)
						qs.setQuestVar(7);
					return defaultOnKillEvent(env, targetId, 0, 3, 2);
			}
		}
		return false;
	}
	
	public boolean onAtDistanceEvent(QuestEnv env) {
		return defaultFollowEndEvent(env, 7, 8, true);
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
