/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.LF6;

import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.HandlerResult;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;


/**
 * @author 81002
 *
 */
public class _10525AgentVindaCall extends QuestHandler {

	private final static int questId = 10525;

	public _10525AgentVindaCall() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(806075).addOnTalkEvent(questId);
		qe.registerQuestNpc(806134).addOnTalkEvent(questId);
		qe.registerQuestNpc(806224).addOnTalkEvent(questId);
		qe.registerQuestNpc(806225).addOnTalkEvent(questId);
		qe.registerQuestNpc(806226).addOnTalkEvent(questId);
		qe.registerQuestNpc(806227).addOnTalkEvent(questId);
		qe.registerQuestItem(182216072, questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		int var = qs.getQuestVarById(0);
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 806075:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 806134:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 1)
							  return sendQuestDialog(env, 1352);
							else if (var == 3)
								return sendQuestDialog(env, 2034);
							else if (var == 4)
								return sendQuestDialog(env, 2375);
							else if (var == 5)
								return sendQuestDialog(env, 2716);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
						case STEP_TO_4:
							return defaultCloseDialog(env, 3, 4);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 4, 5, false, 10000, 10001);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6);
					}
					break;
				case 806224:
					switch(env.getDialog()) { // 1
						case START_DIALOG:
							return sendQuestDialog(env, 1694);
						case FINISH_DIALOG:
							int var1 = qs.getQuestVarById(1) + 1;
							qs.setQuestVarById(1, var1);
							if (var1 == 15)
								qs.setQuestVarById(0, 3);
							updateQuestStatus(env);
							return closeDialogWindow(env);
					}
					break;
				case 806225:
					switch(env.getDialog()) { // 2
						case START_DIALOG:
							return sendQuestDialog(env, 1779);
						case FINISH_DIALOG:
							int var1 = qs.getQuestVarById(1) + 2;
							qs.setQuestVarById(1, var1);
							if (var1 == 15)
								qs.setQuestVarById(0, 3);
							updateQuestStatus(env);
							return closeDialogWindow(env);
					}
					break;
				case 806226:
					switch(env.getDialog()) { // 4
						case START_DIALOG:
							return sendQuestDialog(env, 1864);
						case FINISH_DIALOG:
							int var1 = qs.getQuestVarById(1) + 4;
							qs.setQuestVarById(1, var1);
							if (var1 == 15)
								qs.setQuestVarById(0, 3);
							updateQuestStatus(env);
							return closeDialogWindow(env);
					}
					break;
				case 806227:
					switch(env.getDialog()) { // 8
						case START_DIALOG:
							return sendQuestDialog(env, 1949);
						case FINISH_DIALOG:
							int var1 = qs.getQuestVarById(1) + 8;
							qs.setQuestVarById(1, var1);
							if (var1 == 15)
								qs.setQuestVarById(0, 3);
							updateQuestStatus(env);
							return closeDialogWindow(env);
					}
					break;
			}
		}
		return false;
	}
	
	@Override
	public HandlerResult onItemUseEvent(QuestEnv env, Item item) {
		return HandlerResult.fromBoolean(useQuestItem(env, item, 6, 6, true));
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
