/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.eltnen;

import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.teleport.TeleportService2;

/**
 * @author 81002
 */
public class _14026StopattackingElTenney extends QuestHandler {

	private final static int questId = 14026;

	public _14026StopattackingElTenney() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(203901).addOnTalkEvent(questId);
		qe.registerQuestNpc(204020).addOnTalkEvent(questId);
		qe.registerQuestNpc(204044).addOnTalkEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		int var = qs.getQuestVarById(0);
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 203901:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_1:
							changeQuestStep(env, 0, 1, false);
							return TeleportService2.teleportTo(player, 210020000, 1609.6808f, 1528.5233f, 318.0651f, (byte)118, TeleportAnimation.BEAM_ANIMATION);
					}
					break;
				case 204020:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 3057);
						case STEP_TO_2:
							giveQuestItem(env, 182215324, 1);
							changeQuestStep(env, 1, 2, false);
							return TeleportService2.teleportTo(player, 210020000, 2502.1602f, 782.7755f, 408.9833f, (byte)15, TeleportAnimation.BEAM_ANIMATION);
					}
					break;
				case 204044:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 2)
								return sendQuestDialog(env, 3398);
							else if (var == 4)
								return sendQuestDialog(env, 2034);
						case STEP_TO_3:
							changeQuestStep(env, 2, 4, false);
							return closeDialogWindow(env);
						case STEP_TO_4:
							changeQuestStep(env, 4, 4, true);
							return TeleportService2.teleportTo(player, 210020000, 264.935f, 2792.876f, 272.477f, (byte)45, TeleportAnimation.BEAM_ANIMATION);
					}
			}
		}
		else {
			if (targetId == 203901 && qs.getStatus() == QuestStatus.REWARD) {
				switch(env.getDialog()) {
					case START_DIALOG:
						return sendQuestDialog(env, 2375);
				}
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 14020, true);
	}
}
