/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.gelkmaros;

import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.QuestService;
import com.aionemu.gameserver.services.instance.InstanceService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.world.WorldMapInstance;


/**
 * @author 81002
 *
 */
public class _20034SaveTheKiteRace extends QuestHandler {

	private final static int questId = 20034;
	
	public _20034SaveTheKiteRace() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(799297).addOnTalkEvent(questId);
		qe.registerQuestNpc(799295).addOnTalkEvent(questId);
		qe.registerQuestNpc(730243).addOnTalkEvent(questId);
		qe.registerQuestNpc(799513).addOnTalkEvent(questId);
		qe.registerQuestNpc(799514).addOnTalkEvent(questId);
		qe.registerQuestNpc(799515).addOnTalkEvent(questId);
		qe.registerQuestNpc(799516).addOnTalkEvent(questId);
		qe.registerQuestNpc(799341).addOnTalkEvent(questId);
		qe.registerQuestNpc(216592).addOnKillEvent(questId);
		qe.registerOnEnterWorld(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		if (qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 799297:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 799295:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
					}
					break;
				case 730243:
					switch(env.getDialog()) {
						case USE_OBJECT:
							if (useQuestObject(env, 2, 2, false, false))
								return sendQuestDialog(env, 1693);
							break;
						case STEP_TO_3:
							WorldMapInstance newInstance = InstanceService.getNextAvailableInstance(300150000, 0);
							InstanceService.registerPlayerWithInstance(newInstance, player);
							TeleportService2.teleportTo(player, 300150000, newInstance.getInstanceId(), 561.7141f, 221.8086f, 134.4664f, (byte) 90, TeleportAnimation.BEAM_ANIMATION);
							changeQuestStep(env, 2, 3, false);
							return closeDialogWindow(env);
					}
					break;
				case 799513:
				case 799514:
				case 799515:
				case 799516:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							QuestService.addNewSpawn(300150000, player.getInstanceId(), 216592, 561.8701f, 189.7175f, 135.8892f, (byte) 30);
							return defaultCloseDialog(env, 3, 4);
					}
					break;
				case 799341:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 799295) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onEnterWorldEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null || qs.getStatus() != QuestStatus.START)
			return false;
		int var = qs.getQuestVarById(0);
		if (player.getWorldId() == 220070000) {
			if (var >= 3 && var < 6) {
				qs.setQuestVar(2);
				updateQuestStatus(env);
				return true;
			}
			else if (var == 6){
				changeQuestStep(env, 6, 7, true);
				return true;
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		if (defaultOnKillEvent(env, 216592, 4, false)) {
			QuestService.addNewSpawn(300150000, env.getPlayer().getInstanceId(), 799341, 559.3846f, 185.2943f, 135.8892f, (byte)23);
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 20031, true);
	}
}
