/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.heiron;

import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.teleport.TeleportService2;


/**
 * @author 81002
 *
 */
public class _14053Anotherthreat extends QuestHandler {

	private final static int questId = 14053;
	
	public _14053Anotherthreat() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(204602).addOnTalkEvent(questId);
		qe.registerQuestNpc(204020).addOnTalkEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		int var = qs.getQuestVarById(0);
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 204602:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 0)
								return sendQuestDialog(env, 1011);
							else if (var == 2)
								return sendQuestDialog(env, 1693);
							else if (var == 3)
								return sendQuestDialog(env, 2034);
						case STEP_TO_1:
							changeQuestStep(env, 0, 1, false);
							return TeleportService2.teleportTo(player, 210020000, 1610.4354f, 1528.7382f, 318.0651f, (byte)117, TeleportAnimation.BEAM_ANIMATION);
						case STEP_TO_3:
							changeQuestStep(env, 2, 3, false);
							return closeDialogWindow(env);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 3, 4, true, 10000, 10001);
					}
					break;
				case 204020:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							changeQuestStep(env, 1, 2, false);
							return TeleportService2.teleportTo(player, 210040000, 2010.4641f, 1394.5402f, 118.125f, (byte)5, TeleportAnimation.BEAM_ANIMATION);
					}
			}
		}
		else {
			if (targetId == 204602 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.START_DIALOG)
					return sendQuestDialog(env, 2375);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 14050, true);
	}
}
