/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.heiron;

import java.util.Arrays;
import java.util.List;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;


/**
 * @author 81002
 *
 */
public class _14054MagnaBloodyMap extends QuestHandler {

	private final static int questId = 14054;
	private final static List<Integer> mob_ids = Arrays.asList(235483, 235484, 235485, 235486, 235487, 235488, 235489, 235490, 235491, 235492, 235493, 235494, 235495, 235496, 235497, 235498, 235499, 235500, 235501, 235502);

	public _14054MagnaBloodyMap() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(204602).addOnTalkEvent(questId);
		qe.registerQuestNpc(800413).addOnTalkEvent(questId);
		qe.registerQuestNpc(702040).addOnKillEvent(questId);
		qe.registerQuestNpc(802050).addOnTalkEvent(questId);
		qe.registerQuestNpc(284903).addOnKillEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
		for(int id : mob_ids)
			qe.registerQuestNpc(id).addOnKillEvent(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		int var = qs.getQuestVarById(0);
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 204602:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1097);
						case STEP_TO_1:
							changeQuestStep(env, 0, 1, false);
							return closeDialogWindow(env);
					}
					break;
				case 800413:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1438);
						case STEP_TO_2:
							changeQuestStep(env, 1, 2, false);
							return closeDialogWindow(env);
					}
					break;
				case 802050:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2120);
						case STEP_TO_4:
							changeQuestStep(env, 2, 3, false);
							return closeDialogWindow(env);
						case USE_OBJECT:
							if (var == 4)
								return sendQuestDialog(env, 2802);
						case STEP_TO_6:
							changeQuestStep(env, 4, 4, true);
							return closeDialogWindow(env);
					}
					break;
			}
		}
		else if (targetId == 800413 && qs.getStatus() == QuestStatus.REWARD) {
			if (env.getDialog() == QuestDialog.USE_OBJECT) {
				return sendQuestDialog(env, 3057);
			}
			return sendQuestEndDialog(env);
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		if (mob_ids.contains(targetId))
			return defaultOnKillEvent(env, targetId, 0, 6, 1);
		else if (targetId == 702040)
			return defaultOnKillEvent(env, targetId, 0, 3, 2);
		else if (targetId == 284903) 
			return defaultOnKillEvent(env, targetId, 3, 4);
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 14050, true);
	}
}
