/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.inggison;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;

/**
 * @author 81002
 */
public class _10033PetrochemicalEntity extends QuestHandler {

	private final static int questId = 10033;

	public _10033PetrochemicalEntity() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(798970).addOnTalkEvent(questId);
		qe.registerQuestNpc(798975).addOnTalkEvent(questId);
		qe.registerQuestNpc(798981).addOnTalkEvent(questId);
		qe.registerQuestNpc(730226).addOnTalkEvent(questId);
		qe.registerQuestNpc(730227).addOnTalkEvent(questId);
		qe.registerQuestNpc(730228).addOnTalkEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		int var = qs.getQuestVarById(0);
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 798970:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 798975:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 1)
								return sendQuestDialog(env, 1352);
							else if (var == 6)
								return sendQuestDialog(env, 3057);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
						case SELECT_ACTION_3058:
							removeQuestItem(env, 182215625, 1);
							return sendQuestDialog(env, 3058);
						case SET_REWARD:
							qs.setQuestVarById(0, 7);
							qs.setStatus(QuestStatus.REWARD);
							updateQuestStatus(env);
							return defaultCloseDialog(env, 7, 7);
					}
					break;
				case 798981:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							giveQuestItem(env, 182215622, 1);
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 730226:
					switch(env.getDialog()) {
						case USE_OBJECT:
							useQuestObject(env, 3, 3, false, false);
							return sendQuestDialog(env, 2034);
						case STEP_TO_4:
							removeQuestItem(env, 182215622, 1);
							giveQuestItem(env, 182215623, 1);
							return defaultCloseDialog(env, 3, 4);
					}
					break;
				case 730227:
					switch(env.getDialog()) {
						case USE_OBJECT:
							useQuestObject(env, 4, 4, false, false);
							return sendQuestDialog(env, 2375);
						case STEP_TO_5:
							removeQuestItem(env, 182215623, 1);
							giveQuestItem(env, 182215624, 1);
							return defaultCloseDialog(env, 4, 5);
					}
					break;
				case 730228:
					switch(env.getDialog()) {
						case USE_OBJECT:
							useQuestObject(env, 5, 5, false, false);
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							removeQuestItem(env, 182215624, 1);
							giveQuestItem(env, 182215625, 1);
							return defaultCloseDialog(env, 5, 6);
					}
					break;
			}
		}
		else {
			if (targetId == 798970 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
