/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.inggison;

import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.HandlerResult;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.QuestService;
import com.aionemu.gameserver.services.instance.InstanceService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.world.WorldMapInstance;


/**
 * @author 81002
 *
 */
public class _10034UndergroundTempleSpace extends QuestHandler {

	private final static int questId = 10034;

	public _10034UndergroundTempleSpace() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(799030).addOnTalkEvent(questId);
		qe.registerQuestNpc(799029).addOnTalkEvent(questId);
		qe.registerQuestNpc(798990).addOnTalkEvent(questId);
		qe.registerQuestNpc(730295).addOnTalkEvent(questId);
		qe.registerQuestNpc(700604).addOnTalkEvent(questId);
		qe.registerQuestNpc(216531).addOnKillEvent(questId);
		qe.registerQuestNpc(730229).addOnTalkEvent(questId);
		qe.registerQuestItem(182215628, questId);
		qe.registerOnEnterWorld(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 799030:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 799029:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
					}
					break;
				case 798990:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 730295:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2034);
						case STEP_TO_4:
							if (QuestService.collectItemCheck(env, true)) {
								changeQuestStep(env, 3, 4, false);
								WorldMapInstance newInstance = InstanceService.getNextAvailableInstance(300160000, 0);
								InstanceService.registerPlayerWithInstance(newInstance, player);
								return TeleportService2.teleportTo(player, 300160000, newInstance.getInstanceId(), 800.34f, 886.76f, 149.51f, (byte)60, TeleportAnimation.BEAM_ANIMATION);
							}
							return sendQuestDialog(env, 10001);
					}
					break;
				case 700604:
					switch(env.getDialog()) {
						case USE_OBJECT:
							return useQuestObject(env, 4, 5, false, false);
					}
					break;
				case 730229:
					switch(env.getDialog()) {
						case USE_OBJECT:
							useQuestObject(env, 6, 6, false, false);
							return sendQuestDialog(env, 3057);
						case STEP_TO_7:
							giveQuestItem(env, 182215628, 1);
							return defaultCloseDialog(env, 6, 7);
					}
					break;
			}
		}
		else {
			if (targetId == 799030 && qs.getStatus() == QuestStatus.REWARD) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public HandlerResult onItemUseEvent(QuestEnv env, Item item) {
		Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			int var = qs.getQuestVarById(0);
			int itemId = item.getItemId();
			if (itemId == 182215628) {
				if (var == 7) {
					qs.setQuestVarById(0, 8);
					qs.setStatus(QuestStatus.REWARD);
					updateQuestStatus(env);
					return HandlerResult.SUCCESS;
				}
			}
		}
		return HandlerResult.UNKNOWN;
	}
	
	@Override
	public boolean onEnterWorldEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		if (player.getWorldId() != 300160000) {
			final QuestState qs = player.getQuestStateList().getQuestState(questId);
			if (qs == null)
				return false;
			int var = qs.getQuestVarById(0);
			if (var > 3 && var < 7) {
				changeQuestStep(env, var, 3, false);
				return true;
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		return defaultOnKillEvent(env, 216531, 5, false);
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
