/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.reshanta;

import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.HandlerResult;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.teleport.TeleportService2;

/**
 * @author 81002
 */
public class _14043Thelanguagelearning extends QuestHandler {

	private final static int questId = 14043;

	public _14043Thelanguagelearning() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(278532).addOnTalkEvent(questId);
		qe.registerQuestNpc(798026).addOnTalkEvent(questId);
		qe.registerQuestNpc(798025).addOnTalkEvent(questId);
		qe.registerQuestNpc(279019).addOnTalkEvent(questId);
		qe.registerQuestItem(182215351, questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		int var = qs.getQuestVarById(0);
		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();
		if (qs != null && qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 278532:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 798026:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 1)
								return sendQuestDialog(env, 1352);
							else if (var == 4)
								return sendQuestDialog(env, 2375);
							else if (var == 6 || var == 8)
								return sendQuestDialog(env, 3057);
						case STEP_TO_11:
							if (player.getInventory().tryDecreaseKinah(20000)) {
								if (giveQuestItem(env, 182215351, 1))
									return defaultCloseDialog(env, 1, 7);
							}
							else {
								return sendQuestDialog(env, 1355);
							}
							break;
						case STEP_TO_12:
							return defaultCloseDialog(env, 1, 2);
						case STEP_TO_5:
							return defaultCloseDialog(env, 4, 5, 182215351, 1, 182215352, 1);
						case STEP_TO_7:
							qs.setStatus(QuestStatus.REWARD);
							updateQuestStatus(env);
							TeleportService2.teleportTo(player, 400010000, 2369.1333f, 554.2001f, 1538.9125f, (byte)100, TeleportAnimation.BEAM_ANIMATION);
							return closeDialogWindow(env);
					}
					break;
				case 798025:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 279019:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2034);
						case STEP_TO_4:
							return defaultCloseDialog(env, 3, 4, 182215352, 1, 0, 0);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 278532) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public HandlerResult onItemUseEvent(QuestEnv env, Item item) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return HandlerResult.UNKNOWN;
		int var = qs.getQuestVarById(0);
		if (var == 5) {
			return HandlerResult.fromBoolean(useQuestItem(env, item, 5, 6, false));
		}
		else if (var == 7) {
			return HandlerResult.fromBoolean(useQuestItem(env, item, 7, 8, false));
		}
		return HandlerResult.UNKNOWN;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}
	
	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 14040, true);
	}
}
