/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.verteron;

import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.HandlerResult;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.world.zone.ZoneName;

/**
 * @author 81002
 *
 */
public class _14014Investigationplot extends QuestHandler {

	private final static int questId = 14014;
	
	private final static int[] npcs = { 203146, 802045, 203098, 203147 };
	private final static int[] mobs = { 210168, 210178, 210356, 210186, 216892 };
	
	public _14014Investigationplot() {
		super(questId);
	}
	
	@Override
	public void register() {
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
		for (int npc : npcs)
			qe.registerQuestNpc(npc).addOnTalkEvent(questId);
		qe.registerQuestItem(182215314, questId);
		for (int mob : mobs)
			qe.registerQuestNpc(mob).addOnKillEvent(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		final int var = qs.getQuestVarById(0);
		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();

		if (qs.getStatus() == QuestStatus.START) {
			switch (targetId) {
				case 203146:
					if (var == 0 && env.getDialog() == QuestDialog.START_DIALOG)
						return sendQuestDialog(env, 1352);
					if (env.getDialog() == QuestDialog.STEP_TO_1)
						return defaultCloseDialog(env, 0, 1, 182215314, 1, 0, 0);
					break;
				case 203147:
					if (var == 2 && env.getDialog() == QuestDialog.START_DIALOG)
						return sendQuestDialog(env, 3398);
					if (env.getDialog() == QuestDialog.STEP_TO_3)
						return defaultCloseDialog(env, 2, 3);
					break;
				case 802045:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2034);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 3, 4, false, 2375, 2120);
						case SELECT_ACTION_2376:
							return defaultCloseDialog(env, 4, 5);
					}
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 203098) { // Spatalos
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 3057);
				else
					return sendQuestEndDialog(env);
			}
		}
		return false;
	}

	@Override
	public HandlerResult onItemUseEvent(QuestEnv env, final Item item) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null || qs.getStatus() != QuestStatus.START)
			return HandlerResult.UNKNOWN;
		int var = qs.getQuestVarById(0);

		final int id = item.getItemTemplate().getTemplateId();

		if (id == 182215314)
			if (var == 1 && player.isInsideZone(ZoneName.get("LF1_SZ_TURSINUKA_210030000")))
				return HandlerResult.fromBoolean(useQuestItem(env, item, 1, 2, false, 18));
		return HandlerResult.FAILED;
	}

	@Override
	public boolean onKillEvent(QuestEnv env) {
		Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null || qs.getStatus() != QuestStatus.START)
			return false;

		int var = qs.getQuestVarById(0);
		boolean reward = var == 7;
		return defaultOnKillEvent(env, mobs, var, reward);
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 14010, true);
	}
}
