/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.zone118;

import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.instance.InstanceService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.world.WorldMapInstance;


/**
 * @author 81002
 *
 */
public class _20101thedaybefore extends QuestHandler {

	private static final int questId = 20101;
	/**
	 * @param questId
	 */
	public _20101thedaybefore() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(802463).addOnTalkEvent(questId);
		qe.registerQuestNpc(731531).addOnTalkEvent(questId);
		qe.registerQuestNpc(234680).addOnKillEvent(questId);
		qe.registerQuestNpc(234193).addOnKillEvent(questId);
		qe.registerQuestNpc(804556).addOnTalkEvent(questId);
		qe.registerQuestNpc(731532).addOnTalkEvent(questId);
		qe.registerQuestNpc(802361).addOnTalkEvent(questId);
		qe.registerQuestNpc(802433).addOnTalkEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int var = qs.getQuestVarById(0);
		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();

		if (qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 802463:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1, 182215523, 1, 0, 0);
					}
					break;
				case 731531:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							if (player.getInventory().getItemCountByItemId(182215523) >= 1) {
								WorldMapInstance newInstance = InstanceService.getNextAvailableInstance(301270000, 0);
								InstanceService.registerPlayerWithInstance(newInstance, player);
								TeleportService2.teleportTo(player, 301270000, newInstance.getInstanceId(), 361f, 260f, 311.365f, (byte) 60, TeleportAnimation.BEAM_ANIMATION);
								return defaultCloseDialog(env, 1, 2, 0, 0, 182215523, 1);
							}
					}
					break;
				case 804556:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6, 182215522, 1, 0, 0);
					}
					break;
				case 731532:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 3057);
						case STEP_TO_7:
							TeleportService2.teleportTo(player, 600090000, 330.7953f, 926.1501f, 89.875f, (byte)0, TeleportAnimation.BEAM_ANIMATION);
							return defaultCloseDialog(env, 6, 7);
					}
					break;
				case 802361:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 7)
								return sendQuestDialog(env, 3398);
							else if (var == 8)
								return sendQuestDialog(env, 3739);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 7, 8, false, 10000, 10001);
						case SET_REWARD:
							changeQuestStep(env, 8, 8, true);
							TeleportService2.teleportTo(player, 600090000, 406.857f, 1355.9812f, 163.6786f, (byte)80, TeleportAnimation.BEAM_ANIMATION);
							return closeDialogWindow(env);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 802433) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		final QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;
		int var = qs.getQuestVarById(0);
		int targetId = env.getTargetId();
		if (var == 4 && targetId == 234193) {
			return defaultOnKillEvent(env, 234193, var, false);
		}
		else if (var > 1 && var < 4) {
		  return defaultOnKillEvent(env, 234680, var, false);
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
