/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.zone135;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.QuestService;
import com.aionemu.gameserver.utils.PacketSendUtility;

/**
 * @author 81002
 */
public class _20504Tiamat extends QuestHandler {

	private static final int questId = 20504;
	private static final int[] mob_ids = new int[] { 219943, 219944, 219945, 219946, 219947, 219948, 219949 };

	/**
	 * @param questId
	 */
	public _20504Tiamat() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(804730).addOnTalkEvent(questId);
		qe.registerQuestNpc(804742).addOnTalkEvent(questId);
		qe.registerQuestNpc(804731).addOnTalkEvent(questId);
		for (int id : mob_ids)
			qe.registerQuestNpc(id).addOnKillEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}

	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int var = qs.getQuestVarById(0);
		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();

		if (qs.getStatus() == QuestStatus.START) {
			switch (targetId) {
				case 804730:
					switch (env.getDialog()) {
						case START_DIALOG:
							if (var == 0)
								return sendQuestDialog(env, 1011);
							else if (var == 2)
								return sendQuestDialog(env, 1693);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 804742:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6);
					}
					break;
				case 804731:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 3057);
						case SET_REWARD:
							return defaultCloseDialog(env, 6, 7, true, false);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 804730) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}

	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null || qs.getStatus() != QuestStatus.START)
			return false;
		
		int var = qs.getQuestVarById(0);
		int[] mobs = new int[]{};
		if (var == 1)
			mobs = new int[] {219943,219944,219945};
		else if (var == 3)
			mobs = new int[] {219946,219947,219948};
		PacketSendUtility.sendMessage(player, "Var: " + var);
		if (var == 1 || var == 3) {
			int var1 = qs.getQuestVarById(1);
			if (var1 < 4)
				return defaultOnKillEvent(env, mobs, 0, 5, 1);
			else if (var1 == 4) {
				qs.setQuestVarById(1, 0);
				return defaultOnKillEvent(env, mobs, var, false);
			}
		}
		else if (var == 4) {
			if (defaultOnKillEvent(env, 219949, 4, false)){
				QuestService.addNewSpawn(220080000, player.getInstanceId(), 804742, 1212f, 1635f, 321f, (byte)73);
				return true;
			}
		}
		return false;
	}

	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 20500, true);
	}
}
