/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.zone135;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.QuestService;
import com.aionemu.gameserver.world.zone.ZoneName;


/**
 * @author 81002
 *
 */
public class _20506Suspiciousbattle extends QuestHandler {

	private static final int questId = 20506;
	/**
	 * @param questId
	 */
	public _20506Suspiciousbattle() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(804736).addOnTalkEvent(questId);
		qe.registerQuestNpc(804737).addOnTalkEvent(questId);
		qe.registerQuestNpc(804743).addOnTalkEvent(questId);
		qe.registerOnEnterZone(ZoneName.get("SUBZONE_EVENT_04_220080000"), questId);
		qe.registerQuestNpc(219956).addOnKillEvent(questId);
		qe.registerQuestNpc(219957).addOnKillEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int var = qs.getQuestVarById(0);
		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();

		if (qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 804736:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
					}
					break;
				case 804737:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 1)
								return sendQuestDialog(env, 1352);
							else if (var == 6)
								return sendQuestDialog(env, 3057);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
						case SET_REWARD:
							return defaultCloseDialog(env, 6, 7, true, false);
					}
					break;
				case 804743:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 804736) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onKillEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int var = qs.getQuestVarById(0);
		int targetId = env.getTargetId();
		switch(targetId) {
			case 219956:
				if (var == 3)
					QuestService.addNewSpawn(220080000, env.getVisibleObject().getInstanceId(), 219957, 1929.89f, 76.456f, 234.875f, (byte)0);
				return defaultOnKillEvent(env, 219956, 3, false);
			case 219957:
				return defaultOnKillEvent(env, 219957, 4, false);
		}
		return false;
	}
	
	@Override
	public boolean onEnterZoneEvent(QuestEnv env, ZoneName zoneName) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int var = qs.getQuestVarById(0);
		if (var == 2) {
			changeQuestStep(env, 2, 3, false);
			QuestService.addNewSpawn(220080000, env.getVisibleObject().getInstanceId(), 219956, 1929.89f, 76.456f, 234.875f, (byte)0);
			return true;
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env, 20500, true);
	}
}
