/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.zone154;

import com.aionemu.gameserver.model.TeleportAnimation;
import com.aionemu.gameserver.model.gameobjects.Item;
import com.aionemu.gameserver.model.gameobjects.LetterType;
import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.HandlerResult;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;
import com.aionemu.gameserver.services.instance.InstanceService;
import com.aionemu.gameserver.services.mail.SystemMailService;
import com.aionemu.gameserver.services.teleport.TeleportService2;
import com.aionemu.gameserver.world.WorldMapInstance;

/**
 * @author zxl001
 */
public class _20520Lostfate extends QuestHandler {

	private final static int questId = 20520;

	/**
	 * @param questId
	 */
	public _20520Lostfate() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerOnLevelUp(questId);
		qe.registerOnLogOut(questId);
		qe.registerQuestNpc(204075).addOnTalkEvent(questId);
		qe.registerQuestItem(182215974, questId);
		qe.registerQuestNpc(806077).addOnTalkEvent(questId);
		qe.registerQuestNpc(204191).addOnTalkEvent(questId);
		qe.registerQuestNpc(806080).addOnTalkEvent(questId);
		qe.registerOnEnterWorld(questId);
		qe.registerOnMovieEndQuest(868, questId);
	}

	@Override
	public boolean onDialogEvent(QuestEnv env) {
		Player player = env.getPlayer();
		int targetId = env.getTargetId();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null || qs.getStatus() == QuestStatus.NONE)
			return false;

		if (qs.getStatus() == QuestStatus.START) {
			switch (targetId) {
				case 204075:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1011);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1, 182215974, 1, 0, 0);
					}
				case 806077:
					switch (env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3, 182215954, 1, 0, 0);
					}
					break;
				case 204191:
					switch (env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2034);
						case STEP_TO_4:
							player.getInventory().decreaseByItemId(182215954, 1);
							TeleportService2.teleportTo(player, 220110000, 1806.0f, 1986.0f, 197.80386f, (byte) 0, TeleportAnimation.BEAM_ANIMATION);
							changeQuestStep(env, 3, 4, false);
							return closeDialogWindow(env);
					}
					break;
				case 806080:
					switch (env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case SET_REWARD:
							changeQuestStep(env, 5, 6, true);
							updateQuestStatus(env);
							return sendQuestDialog(env, 10002);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (env.getDialog() == QuestDialog.SELECT_REWARD) {
				return sendQuestEndDialog(env);
			}
			else {
				Npc npc = player.getPosition().getWorldMapInstance().getNpc(806080);
				npc.getController().delete();
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}

	@Override
	public HandlerResult onItemUseEvent(final QuestEnv env, Item item) {
		return HandlerResult.fromBoolean(useQuestItem(env, item, 1, 2, false, 0, 0, 0));
	}
	
	@Override
	public boolean onEnterWorldEvent(QuestEnv env) {
		Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null || qs.getStatus() != QuestStatus.START)
			return false;
		
		int var = qs.getQuestVars().getQuestVars();
		
		if (var == 4 && player.getWorldId() == 220110000) {
			playQuestMovie(env, 868);
			return true;
		}
		return false;
	}

	@Override
	public boolean onMovieEndEvent(QuestEnv env, int movieId) {
		if (movieId == 868) {
			WorldMapInstance newInstance = InstanceService.getNextAvailableInstance(301580000, 0);
			InstanceService.registerPlayerWithInstance(newInstance, env.getPlayer());
			TeleportService2.teleportTo(env.getPlayer(), 301580000, newInstance.getInstanceId(), 432.54764f, 492.83694f, 99.59915f, (byte) 90);
			changeQuestStep(env, 4, 5, false);
			return true;
		}
		return false;
	}
	
	@Override
	public boolean onLogOutEvent(QuestEnv env) {
		Player player = env.getPlayer();
		if (player != null) {
			QuestState qs = player.getQuestStateList().getQuestState(questId);
			if (qs != null && qs.getStatus() == QuestStatus.START) {
				int var = qs.getQuestVars().getQuestVars();
				if (var > 2)
					qs.setQuestVar(2);
			}
		}
		return false;
	}
}
