/*
 * This file is part of aion-lightning <aion-lightning.com>.
 *
 *  aion-lightning is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  aion-lightning is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with aion-lightning.  If not, see <http://www.gnu.org/licenses/>.
 */
package quest.zone175;

import com.aionemu.gameserver.model.gameobjects.Npc;
import com.aionemu.gameserver.model.gameobjects.player.Player;
import com.aionemu.gameserver.questEngine.handlers.QuestHandler;
import com.aionemu.gameserver.questEngine.model.QuestDialog;
import com.aionemu.gameserver.questEngine.model.QuestEnv;
import com.aionemu.gameserver.questEngine.model.QuestState;
import com.aionemu.gameserver.questEngine.model.QuestStatus;


/**
 * @author 81002
 *
 */
public class _20530OraclecallBadel extends QuestHandler {

	private static final int questId = 20530;
	/**
	 * @param questId
	 */
	public _20530OraclecallBadel() {
		super(questId);
	}

	@Override
	public void register() {
		qe.registerQuestNpc(204075).addOnTalkEvent(questId);
		qe.registerQuestNpc(204182).addOnTalkEvent(questId);
		qe.registerQuestNpc(703388).addOnTalkEvent(questId);
		qe.registerQuestNpc(798443).addOnTalkEvent(questId);
		qe.registerQuestNpc(204173).addOnTalkEvent(questId);
		qe.registerQuestNpc(806556).addOnTalkEvent(questId);
		qe.registerQuestNpc(703395).addOnTalkEvent(questId);
		qe.registerQuestNpc(703389).addOnTalkEvent(questId);
		qe.registerQuestNpc(703391).addOnTalkEvent(questId);
		qe.registerOnEnterZoneMissionEnd(questId);
		qe.registerOnLevelUp(questId);
	}
	
	@Override
	public boolean onDialogEvent(QuestEnv env) {
		final Player player = env.getPlayer();
		QuestState qs = player.getQuestStateList().getQuestState(questId);
		if (qs == null)
			return false;

		int var = qs.getQuestVarById(0);
		int targetId = 0;
		if (env.getVisibleObject() instanceof Npc)
			targetId = ((Npc) env.getVisibleObject()).getNpcId();

		if (qs.getStatus() == QuestStatus.START) {
			switch(targetId) {
				case 204075:
					switch(env.getDialog()) {
						case START_DIALOG:
							if (var == 0)
								return sendQuestDialog(env, 1011);
							else if (var == 7)
								return sendQuestDialog(env, 3398);
							else if (var == 8)
								return sendQuestDialog(env, 3739);
						case STEP_TO_1:
							return defaultCloseDialog(env, 0, 1);
						case CHECK_COLLECTED_ITEMS:
							return checkQuestItems(env, 7, 8, false, 10000, 10001);
						case SELECT_REWARD:
							return defaultCloseDialog(env, 8, 9, true, true);
					}
					break;
				case 204182:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 1352);
						case STEP_TO_2:
							return defaultCloseDialog(env, 1, 2);
					}
					break;
				case 703388:
					switch(env.getDialog()) {
						case USE_OBJECT:
							useQuestObject(env, 2, 2, false, false);
							return sendQuestDialog(env, 1693);
						case STEP_TO_3:
							return defaultCloseDialog(env, 2, 3);
					}
					break;
				case 798443:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2034);
						case STEP_TO_4:
							return defaultCloseDialog(env, 3, 4);
					}
					break;
				case 204173:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2375);
						case STEP_TO_5:
							return defaultCloseDialog(env, 4, 5);
					}
					break;
				case 806556:
					switch(env.getDialog()) {
						case START_DIALOG:
							return sendQuestDialog(env, 2716);
						case STEP_TO_6:
							return defaultCloseDialog(env, 5, 6);
					}
					break;
				case 703395:
					switch(env.getDialog()) {
						case USE_OBJECT:
							useQuestObject(env, 6, 6, false, false);
							return sendQuestDialog(env, 3057);
						case STEP_TO_7:
							return defaultCloseDialog(env, 6, 7);
					}
					break;
				case 703389:
				case 703391:
					switch(env.getDialog()) {
						case USE_OBJECT:
							return useQuestObject(env, 7, 7, false, true);
					}
					break;
			}
		}
		else if (qs.getStatus() == QuestStatus.REWARD) {
			if (targetId == 204075) {
				if (env.getDialog() == QuestDialog.USE_OBJECT)
					return sendQuestDialog(env, 10002);
				return sendQuestEndDialog(env);
			}
		}
		return false;
	}
	
	@Override
	public boolean onZoneMissionEndEvent(QuestEnv env) {
		return defaultOnZoneMissionEndEvent(env);
	}

	@Override
	public boolean onLvlUpEvent(QuestEnv env) {
		return defaultOnLvlUpEvent(env);
	}
}
